dissim<-function(...) {
   UseMethod("dissim")
}

dissim.default<-function(Y,X=NULL,Z=NULL) {
	if(is.factor(Y)) Y<-as.otab(Y)
	stopifnot(ncol(Y)!=1)
	## centred abundance table
	N<-sum(Y)
	rw<-rowSums(Y)/N
	cw<-colSums(Y)/N
	Div<-rbind(data.frame(Richness=sum(1-cw),Shannon=sum(cw*log(1/cw)),Simpson=sum(cw*(1-cw)),row.names="Dtot"),DY=if(!is.otab(Y)) divindex(Vinter(Y),cw))
	tab<-t(apply(Y,1,function(x) if(sum(x)==0) cw else x/sum(x)))
	tab<-sweep(tab,2,cw)
	if((!is.null(X))&&(is.null(Z))) {
		## fitted values of Y with respect to X
		if(is.factor(X))
			X<-model.matrix(~X)
		tab<-lm.wfit(y=tab,x=X,w=rw)$fitted.values
	}
	else if((is.null(X))&&(!is.null(Z))) {
		## residual values of Y with respect to X
		if(is.factor(Z))
			Z<-model.matrix(~Z)
		tab<-lm.wfit(y=tab,x=Z,w=rw)$residuals
	}
	else if((!is.null(X))&&(!is.null(Z))) {
		## fitted values of Y knowing Z with respect to X
		if(is.factor(Z))
			Z<-model.matrix(~Z)
		tab<-lm.wfit(y=tab,x=Z,w=rw)$residuals
		if(is.factor(X))
			X<-model.matrix(~X)
		tab<-lm.wfit(tab,x=X,w=rw)$fitted.values
	}
	nl<-nrow(tab)
	nc<-ncol(tab)
    util<-matrix(0,nl,nl)
    index<-cbind(col(util)[col(util)<row(util)],row(util)[col(util)<row(util)])
#    dist<-function(x) {
#        n<-nrow(x<-as.matrix(x))
#        d<-.C("R_distance",
#        x=as.double(x),
#        nr=n,
#        nc=ncol(x),
#        d=double(n*(n - 1)/2),
#        diag=as.integer(FALSE),
#        method=as.integer(1),
#        p=as.double(2),
#        DUP=FALSE,NAOK=TRUE,
#		PACKAGE='diversity.R')$d
#    }
    delta<-matrix(apply(tab,2,dist)^2,ncol=nc)
    res<-alist()
	res$Div<-Div
    res$delta<-data.frame(delta)
    res$weight<-as.numeric(rw[index[,1]]*rw[index[,2]])
    res$dissim<-data.frame(richness=colSums(t(delta)/cw),Shannon=colSums(t(delta)*log(1/cw)/(1-cw)),Simpson=rowSums(delta))
    res$index<-data.frame(ind1=index[,1],ind2=index[,2])
    attr(res,"Size")<-nl
    res$call<-match.call()
	class(res)<-c("div","dissim")
    return(res)
}

dissim.formula<-function(formula,data) {
    if (missing(data)) data<-parent.frame()
    fmla<-Cformula(formula,data)
    Y<-fmla$Y
    X<-fmla$X
    Z<-fmla$Z
    res<-dissim.default(Y,X,Z)
    res$call<-match.call()
    return(res)
}
