plot.div<-function(div.obj,...) {
    UseMethod("plot.div")
}

plot.div.default<-function(dudiv,xax=1,yax=2,labrow="row.names",labsp="sp.names",title=TRUE,eigen="ratio",add.group=NULL,labgroup="levels",...) {
    appel<-as.list(dudiv$call)
    type<-appel[[1]]
    if(dudiv$divopt==1) type<-paste(type,"(Richness;")
    if(dudiv$divopt==2) type<-paste(type,"(Shannon;")
    if(dudiv$divopt==3) type<-paste(type,"(Simpson;")
    def.par <- par(no.readonly = TRUE)
    on.exit(par(def.par))
    nf<-layout(matrix(c(1,2,2,1,2,2,3,4,4,3,4,4),3,4),respect=TRUE)
    par(mar=c(0.1,0.1,0.1,0.1))
    plot.new()
	scatterutil.sub(if(title) paste(type,"F",xax,"-",yax,")"),csub=3,possub="topleft")
	cl<-cbind(dudiv$l1[,xax],dudiv$l1[,yax])
	co<-cbind(dudiv$co[,xax],dudiv$co[,yax])
    s.label(cl,cpoint=if(!identical(labrow,"row.names")||!identical(labrow,"row.codes")) 0 else 1,clabel=0,cgrid=3,csub=3,sub="Sites",possub="topleft")
	if(identical(labrow,"row.names")) text(cl,labels=row.names(dudiv$l1),cex=1.5,...)
	else if(identical(labrow,"row.codes")) text(cl,labels=row(as.matrix(dudiv$l1[,1])),cex=1.5,...)
	else text(cl,labels=as.character(labrow),cex=1.5,...)
	if(!is.null(add.group))
		s.class(cl,add.group,cellipse=0,cstar=0,cpoint=0,label=if(identical(labgroup,"levels")) levels(add.group) else as.character(labgroup),clabel=1.75,add.plot=TRUE,col=seq(1,nlevels(add.group)))
    if(eigen=="ratio") scatterutil.eigen(100*dudiv$eig/sum(dudiv$eig),csub=3,sub="eigenvalues(%)",possub="topright")
    if(eigen=="abs") scatterutil.eigen(dudiv$eig,csub=3,sub="eigenvalues(abs)",possub="topright")
	s.label(co,cpoint=if(labsp=="sp.names"||labsp=="sp.codes") 0 else 1,clabel=0,cgrid=3,csub=3,sub="Species",possub="topleft")
    if(labsp=="sp.names") text(co,labels=row.names(dudiv$co),cex=1.5)
    if(labsp=="sp.codes") text(co,labels=row(as.matrix(dudiv$co[,1])),cex=1.5)
}

plot.div.variodis<-function(x,title=TRUE,xlim=NULL,ylim=NULL,...) {	
    w<-2*x$w
    t<-c("Richness","Shannon","Simpson")
    par(mfrow = c(2,2))
    plot.new()
    if(is.null(x$nrepet)) {
        scatterutil.sub(if(title) paste("Variograms of dissimilarity"),csub=3,possub="topleft")
        matplot(x$h,x$richness,type="l",xlim=xlim,ylim=ylim,xlab="distance, h",ylab="D(h)",main=t[1])
        lines(c(min(x$h),max(x$h)),c(m<-sum(x$richness[,1]*w),m),lty=2)
        matplot(x$h,x$Shannon,type="l",xlim=xlim,ylim=ylim,xlab="distance, h",ylab="D(h)",main=t[2])
        lines(c(min(x$h),max(x$h)),c(m<-sum(x$Shannon[,1]*w),m),lty=2)
        matplot(x$h,x$Simpson,type="l",xlim=xlim,ylim=ylim,xlab="distance, h",ylab="D(h)",main=t[3])
        lines(c(min(x$h),max(x$h)),c(m<-sum(x$Simpson[,1]*w),m),lty=2)
    }
    else {
        scatterutil.sub(if(title) paste("Variograms of dissimilarity\nwith ",100*x$alpha,"% CI",sep=""),csub=3,possub="topleft")
        matplot(x$h,x$richness,type="l",xlim=xlim,ylim=ylim,xlab="distance, h",ylab="D(h)",lty=c(1,3,3),col=1,main=t[1])
        lines(c(min(x$h),max(x$h)),c(m<-sum(x$richness[,1]*w),m),lty=2)
        matplot(x$h,x$Shannon,type="l",xlim=xlim,ylim=ylim,xlab="distance, h",ylab="D(h)",lty=c(1,3,3),col=1,main=t[2])
        lines(c(min(x$h),max(x$h)),c(m<-sum(x$Shannon[,1]*w),m),lty=2)
        matplot(x$h,x$Simpson,type="l",xlim=xlim,ylim=ylim,xlab="distance, h",ylab="D(h)",lty=c(1,3,3),col=1,main=t[3])
        lines(c(min(x$h),max(x$h)),c(m<-sum(x$Simpson[,1]*w),m),lty=2)
    }
    par(mfrow = c(1,1)) 	
}	
