############################################################################
### Total randomization of individual occurrences across the levels of X.###
### Y=dependent species factor; X=explanatory factor.				     ###
### Returns species-variances (opt=NULL) or p-values (opt="pval")		 ###
### between the levels of X.											 ###
############################################################################ 				
testintertot<-function(Y,X,npermut=999,opt=NULL) {
	nsp<-nlevels(Y)
	nlev<-nlevels(X[,1])
	ntot<-length(Y)
	if(is.null(opt))
	## returns a matrix of size (npermut+1)*nsp with first row containing the observed species-variances
		restest<-matrix(.C("testinter1",
			as.integer(Y),
			as.integer(nsp),
			as.integer(X[,1]),
			as.integer(nlev),
			as.integer(ntot),
			as.integer(npermut+1),
			isim=double(nsp*(npermut+1)),
			PACKAGE='diversity.R')$isim,nrow=(npermut+1),ncol=nsp,byrow=TRUE)
	else if(opt=="pval") {
	## returns only the p-values for species-variances (pvalsp) and diversity indices (pvaldiv)
		tmp<-.C("testinter2",
			as.integer(Y),
			as.integer(nsp),
			as.integer(X[,1]),
			as.integer(nlev),
			as.integer(ntot),
			as.integer(npermut+1),
			res=double(nsp+3),
			PACKAGE='diversity.R')$res
		psp<-(tmp[1:nsp]+1)/(npermut+1)
		pdiv<-(tmp[(nsp+1):(nsp+3)]+1)/(npermut+1)
		restest<-list(pvalsp=psp,pvaldiv=pdiv)
	}
	return(restest)
}

############################################################################
### Conditional randomization of individual occurrences across the levels###
### of the second-order factor, X[,2], within the levels of the first-   ###
### order factor, X[,1].												 ###	
### Y=dependent species factor; X=explanatory factors.					 ###
### Returns species-variances (opt=NULL) or p-values (opt="pval")		 ###
### between the levels of the nested factor, X[,2].						 ###
############################################################################ 	
testwithin<-function(Y,X,npermut=999,opt=NULL) {
	gc(verbose=FALSE)
	nsp<-nlevels(Y)
	nlev1<-nlevels(X[,1])
	nlev2<-nlevels(X[,2])
	ntot<-length(Y)
	if(is.null(opt))
	## returns a matrix of size (npermut+1)*nsp with first row containing the observed species-variances
		restest<-matrix(.C("testwithin1",
			as.integer(Y),
			as.integer(nsp),
			as.integer(X[,1]),
			as.integer(nlev1),
			as.integer(X[,2]),
			as.integer(nlev2),
			as.integer(ntot),
			as.integer(npermut),
			isim=double(nsp*(npermut+1)),
			PACKAGE='diversity.R')$isim,nrow=(npermut+1),ncol=nsp,byrow=TRUE)
	else if(opt=="pval") {
	## returns only the p-values for species-variances (pvalsp) and diversity indices (pvaldiv)
		tmp<-.C("testwithin2",
			as.integer(Y),
			as.integer(nsp),
			as.integer(X[,1]),
			as.integer(nlev1),
			as.integer(X[,2]),
			as.integer(nlev2),
			as.integer(ntot),
			as.integer(npermut+1),
			res=double(nsp+3),
			PACKAGE='diversity.R')$res
		psp<-(tmp[1:nsp]+1)/(npermut+1)
		pdiv<-(tmp[(nsp+1):(nsp+3)]+1)/(npermut+1)
		restest<-list(pvalsp=psp,pvaldiv=pdiv)
	}
	return(restest)
}

#idem testwithin2 but send to the C subroutine testwithin2
#packets of 5000 permutations to avoid memory overflow
#testwithin3<-function(Y,X,npermut) {
#	nsp<-nlevels(Y)
#	r<-npermut/5000
#	if(r>1) {
#		nbperm<-vector("integer",ceiling(r))
#		simvec<-rep(5000,(length(nbperm)-1))
#		simvec[length(nbperm)]<-npermut-sum(simvec[1:(length(nbperm)-1)])+1
#	}
#	else
#		simvec<-npermut+1
#	psp<-rep(0,nsp)
#	pdiv<-rep(0,3)
#	for(i in 1:length(simvec)) {
#		tmp<-.C("testwithin2",
#			as.integer(Y),
#			as.integer(nsp),
#			as.integer(X[,1]),
#			as.integer(nlevels(X[,1])),
#			as.integer(X[,2]),
#			as.integer(nlevels(X[,2])),
#			as.integer(length(Y)),
#			as.integer(simvec[i]),
#			res=double(nsp+3),
#			PACKAGE='diversity')$res
#		psp<-psp+tmp[1:nsp]
#		pdiv<-pdiv+tmp[(nsp+1):(nsp+3)]
#	}
#	psp<-(psp+1)/(npermut+1)
#	pdiv<-(pdiv+1)/(npermut+1)
#	return(list(pvalsp=psp,pvaldiv=pdiv))
#}

############################################################################
### Randomization of the levels of the second order factor, X[,2], across###
### the levels of the first order factor, X[,1].						 ###	
### Y=dependent species factor; X=explanatory factors.				     ###
### Returns species-variances (opt=NULL) or p-values (opt="pval")		 ###
### between the levels of the main factor, X[,1].						 ###
############################################################################ 	
testacross<-function(Y,X,npermut=999,opt=NULL) {
	#gc(verbose=FALSE)
	nsp<-nlevels(Y)
	nlev1<-nlevels(X[,1])
	nlev2<-nlevels(X[,2])
	ntot<-length(Y)
	if(is.null(opt))
	## returns a matrix of size (npermut+1)*nsp with first row containing the observed species-variances
		restest<-matrix(.C("testacross1",
			as.integer(Y),
			as.integer(nsp),
			as.integer(X[,1]),
			as.integer(nlev1),
			as.integer(X[,2]),
			as.integer(nlev2),
			as.integer(ntot),
			as.integer(npermut),
			isim=double(nsp*(npermut+1)),
			PACKAGE='diversity.R')$isim,nrow=(npermut+1),ncol=nsp,byrow=TRUE)
	else if(opt=="pval") {
	## returns only the p-values for species-variances (pvalsp) and diversity indices (pvaldiv)
		tmp<-.C("testacross2",
			as.integer(Y),
			as.integer(nsp),
			as.integer(X[,1]),
			as.integer(nlev1),
			as.integer(X[,2]),
			as.integer(nlev2),
			as.integer(ntot),
			as.integer(npermut+1),
			res=double(nsp+3),
			PACKAGE='diversity.R')$res
		psp<-(tmp[1:nsp]+1)/(npermut+1)
		pdiv<-(tmp[(nsp+1):(nsp+3)]+1)/(npermut+1)
		restest<-list(pvalsp=psp,pvaldiv=pdiv)
	}
	return(restest)
}

############################################################################
### Conditional randomization of the levels of the third order factor,   ###
### X[,3], across the levels of the second order factor, X[,2], within   ###
### levels of the first order factor, X[,1].							 ###	
### Y=dependent species factor; X=explanatory factors.				     ###
### Returns species-variances (opt=NULL) or p-values (opt="pval")		 ###
### between the levels of the second level factor, X[,2].				 ###
############################################################################ 	
testacrosswithin<-function(Y,X,npermut=999,opt=NULL) {
	#gc(verbose=FALSE)
	nsp<-nlevels(Y)
	nlev1<-nlevels(X[,1])
	nlev2<-nlevels(X[,2])
	nlev3<-nlevels(X[,3])
	ntot<-length(Y)
	if(is.null(opt))
	## returns a matrix of size (npermut+1)*nsp with first row containing the observed species-variances
		restest<-matrix(.C("testacrosswithin1",
			as.integer(Y),
			as.integer(nsp),
			as.integer(X[,1]),
			as.integer(nlev1),
			as.integer(X[,2]),
			as.integer(nlev2),
			as.integer(X[,3]),
			as.integer(nlev3),
			as.integer(ntot),
			as.integer(npermut),
			isim=double(nsp*(npermut+1)),
			PACKAGE='diversity.R')$isim,nrow=(npermut+1),ncol=nsp,byrow=TRUE)
	else if(opt=="pval") {
	## returns only the p-values for species-variances (pvalsp) and diversity indices (pvaldiv)
		tmp<-.C("testacrosswithin2",
			as.integer(Y),
			as.integer(nsp),
			as.integer(X[,1]),
			as.integer(nlev1),
			as.integer(X[,2]),
			as.integer(nlev2),
			as.integer(X[,3]),
			as.integer(nlev3),
			as.integer(ntot),
			as.integer(npermut+1),
			res=double(nsp+3),
			PACKAGE='diversity.R')$res
		psp<-(tmp[1:nsp]+1)/(npermut+1)
		pdiv<-(tmp[(nsp+1):(nsp+3)]+1)/(npermut+1)
		restest<-list(pvalsp=psp,pvaldiv=pdiv)
	}
	return(restest)
}

########################################################################
### within and between deprecated in ade4, replaced by wca and bca ####
#######################################################################
between <- function(Y,X,scannf = TRUE)
		return(ade4::bca(Y,X,scannf))

within <- function(Y,X,scannf = TRUE)
	return(ade4::wca(Y,X,scannf))

