randtest.div<-function(div.obj,nrepet=999,...) {
    UseMethod("randtest.div")
}

randtest.div.anodiv<-function(div.obj,nrepet=999,...) {
    mod<-as.numeric(div.obj$mod)
    h<-attr(div.obj$mod,"hierarchical")
	call=match.call()
    if(identical(mod,1)) { ## One-way
		t<-testintertot(div.obj$Y,div.obj$X,nrepet)
		dimnames(t)<-list(NULL,levels(div.obj$Y))
		return(apply(t,2,function(x) as.randtest(x[-1],x[1],call=call)))
	}
	else if(identical(mod,c(1,2))) { ## Two-ways nested
        ## randomization of nested units across main factor levels
		t<-testacross(div.obj$Y,div.obj$X,nrepet)
		dimnames(t)<-list(NULL,levels(div.obj$Y))
		main<-apply(t,2,function(x) as.randtest(x[-1],x[1],call=call))
		## conditional randomization of individuals across nested units within main factor levels
        t<-testwithin(div.obj$Y,div.obj$X,nrepet)
		dimnames(t)<-list(NULL,levels(div.obj$Y))
		nest<-apply(t,2,function(x) as.randtest(x[-1],x[1],call=call))
        reslist<-list(main,nest)
    }
	else if(h) { ## Hierarchical
		nfac<-length(mod)
		reslist<-alist()
		## randomization of second-level units across first ranked factor levels
		Xred<-div.obj$X[,1:2]
		t<-testacross(div.obj$Y,Xred,nrepet)
		dimnames(t)<-list(NULL,levels(div.obj$Y))
		reslist[[1]]<-apply(t,2,function(x) as.randtest(x[-1],x[1],call=call))
		## conditional randomization of units of order n+1 across units of order n within units of order n-1
		for(i in 2:(nfac-1)) {
			Xred<-div.obj$X[,(i-1):(i+1)]
			t<-testacrosswithin(div.obj$Y,Xred,nrepet)
			dimnames(t)<-list(NULL,levels(div.obj$Y))
			reslist[[i]]<-apply(t,2,function(x) as.randtest(x[-1],x[1],call=call))
		}
		## conditional randomization of individuals across units of highest order
		Xred<-div.obj$X[,(nfac-1):nfac]
		t<-testwithin(div.obj$Y,Xred,nrepet)
		dimnames(t)<-list(NULL,levels(div.obj$Y))
		reslist[[nfac]]<-apply(t,2,function(x) as.randtest(x[-1],x[1],call=call))
	}
    else stop("randtest not yet implemented for this model")
	names(reslist)<-names(div.obj$X)
	return(reslist)
	
}

randtest.div.dudi<-function(div.obj,nrepet=999,...) {
    UseMethod("randtest.div.dudi")
}

randtest.div.dudi.between<-function(div.obj,nrepet=999,...)
{   ## from the C routine testinter{ade4}
    nrepet<-nrepet+1
    if(length(parsup<-list(...))!=0) {
        appel<-parsup
        dudi1<-appel[[1]]
        fac<-appel[[2]]
        dudi1$Dtot<-appel[[3]]
    }
    else {
        appel<-as.list(div.obj$call)
        dudi1<-eval(appel$dudi,sys.frame(0))
        fac<-eval(appel$fac,sys.frame(0))
    }
    
    tab<-dudi1$tab
    lw<-dudi1$lw
    cw<-dudi1$cw
    isim<-testinter(nrepet,lw,cw,length(unique(fac)),fac,tab,length(lw),length(cw))/dudi1$Dtot
    return(as.randtest(isim[-1],isim[1],call=match.call()))
}

randtest.div.dudi.default<-function(div.obj,nrepet=999,...)
{    	nrepet<-nrepet+1
        if(length(parsup<-list(...))!=0) {
            parsup<-list(...)
            taby<-parsup[[1]]
        }
        else {
            appel<-as.list(div.obj$call)
            taby<-eval(appel$Ytab,sys.frame(0))
	}
        if(all(apply(taby,1,sum)==1))
            stop("no applicable 'randtest' method")
        y<-odf(taby)
        tab<-otab(y[,1])
        N<-sum(tab)
        rw<-rowSums(tab)/N
        cw<-colSums(tab)/N
        tab<-t(apply(tab,1,function(x) if(sum(x)==0) cw else x/sum(x)))
        tab<-sweep(tab,2,cw)
        fac<-y[,2]
        spw<-div.obj$cw
        isim<-testinter(nrepet,rw,spw,length(unique(fac)),fac,tab,length(rw),length(spw))/div.obj$Dtot
        return(as.randtest(isim[-1],isim[1],call=match.call()))
}

randtest.div.dudi.pcaiv<-function(div.obj,nrepet=999,...)
{   ## from a call to the Fortran routine dqrls{base} via lmwfit{diversity}
    cat("Caution: this test is slow.\n")
    if(length(parsup<-list(...))!=0) {
        appel<-parsup
        dudi1<-appel[[1]]
        y<-as.matrix(dudi1$tab)
        x<-appel[[2]]
        dudi1$Dtot<-appel[[3]]
    }
    else {
        appel<-as.list(div.obj$call)
        dudi1<-eval(appel$dudi,sys.frame(0))
        y<-as.matrix(div.obj$Y)
        x<-div.obj$X
    }
    sqlw<-sqrt(dudi1$lw)
    sqcw<-sqrt(dudi1$cw)
    fmla<-as.formula(paste("y ~", paste(dimnames(x)[[2]], collapse = "+")))
    mf<-model.frame(fmla,data=cbind.data.frame(y,x))
    mt<-attr(mf,"terms")
    x<-model.matrix(mt,mf)
    obs<-lmwfit(y,x,sqlw,sqcw)/dudi1$Dtot
    isim<-c()
    for(i in 1:nrepet) isim[i]<-lmwfit(y,x[sample(nrow(x)),],sqlw,sqcw)/dudi1$Dtot
    return(as.randtest(isim,obs,call=match.call()))
}
