variodis<-function(...) {
   UseMethod("variodis")
}

variodis.default<-function(Y,X=NULL,Z=NULL,coords,breaks="Sturges",test=TRUE,nrepet=999,alpha=0.01) {
    stopifnot(ncol(Y)!=1)
	N<-sum(Y)
	rw<-rowSums(Y)/N
	cw<-colSums(Y)/N
	Div<-rbind(data.frame(Richness=sum(1-cw),Shannon=sum(cw*log(1/cw)),Simpson=sum(cw*(1-cw)),row.names="Dtot"),DY=divindex(Vinter(Y),cw))
	tab<-t(apply(Y,1,function(x) if(sum(x)==0) cw else x/sum(x)))
	tab<-sweep(tab,2,cw)
	if((!is.null(X))&&(is.null(Z))) {
		## fitted values of Y with respect to X
		if(is.factor(X))
			X<-model.matrix(~X)
		tab<-lm.wfit(y=tab,x=X,w=rw)$fitted.values
	}
	else if((is.null(X))&&(!is.null(Z))) {
		## residual values of Y with respect to Z
		if(is.factor(Z))
			Z<-model.matrix(~Z)
		tab<-lm.wfit(y=tab,x=Z,w=rw)$residuals
	}
	else if((!is.null(X))&&(!is.null(Z))) {
		## fitted values of Y knowing Z with respect to X
		if(is.factor(Z))
			Z<-model.matrix(~Z)
		tab<-lm.wfit(y=tab,x=Z,w=rw)$residuals
		if(is.factor(X))
			X<-model.matrix(~X)
		tab<-lm.wfit(tab,x=X,w=rw)$fitted.values
	}
	nl<-nrow(tab)
    nc<-ncol(tab)
	util<-matrix(0,nl,nl)
    index<-cbind(col(util)[col(util)<row(util)],row(util)[col(util)<row(util)])
	w<-as.numeric(rw[index[,1]]*rw[index[,2]])
	coords<-data.frame(coords)
	stopifnot(ncol(coords)==2)
	stopifnot(nrow(coords)==nl)
#	distfast<-function(x) {
#        n<-nrow(x<-as.matrix(x))
#		d<-.C("R_distance",
#	    x=as.double(x),
#	    nr=n,
#	    nc=ncol(x),
#	    d=double(n*(n - 1)/2),
#		diag=as.integer(FALSE),
#	    method=as.integer(1),
#	    p = as.double(2),
#		DUP=FALSE,
#		NAOK=TRUE,
#		PACKAGE='diversity.R')$d
#	}

   # weight<-function(x,rw) {
   #     nlig<-nrow(x)
  #  	d<-matrix(0,nlig,nlig)
   # 	d.names<-row.names(x)
   #     index<-cbind(col(d)[col(d)<row(d)],row(d)[col(d)<row(d)])
   #     return(as.numeric(rw[index[,1]]*rw[index[,2]]))
   # }
   # w<-weight(df,rw)
    dw<-apply(tab,2,dist)^2*w
    dw<-apply(dw,1,divindex,cw)
    d<-dist(coords)
    if(is.character(breaks)) {
        if(breaks=="Sturges") {
            nint<-nclass.Sturges(d)
            lint<-(max(d)-min(d))/nint
            inter<-seq(0,nint*lint,lint)
        }
        else if(breaks=="Log") {
            nint<-nclass.Sturges(d)
			#inter<-lseq(min(d),max(d),ninter)
            inter<-seq(0,max(d)-min(d),length=nint)
            inter<-inter*log(inter+1)/log(inter[length(inter)]+1)+min(d)
        }
    }
    else inter<-as.vector(breaks)
    inter[1]<-inter[1]-inter[1]/10e9
    dfac<-as.factor(cut(d,inter,labels=FALSE))
    V<-apply(dw,1,function(x) tapply(x,dfac,sum))
    W<-tapply(w,dfac,sum)
    V<-apply(V,2,function(x) 0.5*x/W)
    res<-alist()
	res$Div<-Div
    if(test) {
    	res$nrepet<-nrepet
        res$alpha<-alpha
        mat1<-matrix(0,nrow=nrow(V),ncol=nrepet)
        mat2<-matrix(0,nrow=nrow(V),ncol=nrepet)
        mat3<-matrix(0,nrow=nrow(V),ncol=nrepet)
#class(d)<-"dist"
#attr(d,"Size")<-nl
		for(i in 1:nrepet) {
            alea<-.Internal(sample(nl,nl,FALSE,NULL))
            #attr(d,"Size")<-nr
            #dsim<-mat2dist(dist2mat(d)[alea,alea])
			#return(d)
			dsim<-as.dist(as.matrix(d)[alea,alea])
            dsimfac<-as.factor(cut(dsim,inter,labels=FALSE))
            Vsim<-apply(dw,1,function(x) tapply(x,dsimfac,sum))
            Wsim<-tapply(w,dsimfac,sum)
            Vsim<-apply(Vsim,2,function(x) 0.5*x/Wsim)
            mat1[,i]<-Vsim[,1]
            mat2[,i]<-Vsim[,2]
            mat3[,i]<-Vsim[,3]
        }
        mat1<-t(apply(mat1,1,sort,method="shell"))
        mat2<-t(apply(mat2,1,sort,method="shell"))
        mat3<-t(apply(mat3,1,sort,method="shell"))
        a1<-floor(alpha*(nrepet+1)/2)
        a2<-nrepet-a1
        if(a1==0) a1<-1
        res$richness<-data.frame(Dh=V[,1],ICn=mat1[,a1],ICp=mat1[,a2])
        res$Shannon<-data.frame(Dh=V[,2],ICn=mat2[,a1],ICp=mat2[,a2])
        res$Simpson<-data.frame(Dh=V[,3],ICn=mat3[,a1],ICp=mat3[,a2])
    }
    else {
    	res$richness<-data.frame(Dh=V[,1])
        res$Shannon<-data.frame(Dh=V[,2])
        res$Simpson<-data.frame(Dh=V[,3])
    }
    util<-inter
    for(i in 2:length(inter)) inter[i]<-(util[i]+util[i-1])/2
    res$h<-inter[-1]
    res$w<-W
    res$call<-match.call()
    class(res)<-c("div","variodis")
    return(res)
}

variodis2<-function(Y,X=NULL,Z=NULL,coords,breaks="Sturges",test=TRUE,nrepet=999,alpha=0.01) {
    stopifnot(inherits(Y,"centered"))
	tab<-Y
	rw<-attr(Y,"rw")
	cw<-attr(Y,"cw")
	Div<-rbind(data.frame(Richness=sum(1-cw),Shannon=sum(cw*log(1/cw)),Simpson=sum(cw*(1-cw)),row.names="Dtot"),DY=divindex(Vinter(Y),cw))
	if((!is.null(X))&&(is.null(Z))) {
		## fitted values of Y with respect to X
		if(is.factor(X))
			X<-model.matrix(~X)
		tab<-lm.wfit(y=tab,x=X,w=rw)$fitted.values
	}
	else if((is.null(X))&&(!is.null(Z))) {
		## residual values of Y with respect to Z
		if(is.factor(Z))
			Z<-model.matrix(~Z)
		tab<-lm.wfit(y=tab,x=Z,w=rw)$residuals
	}
	else if((!is.null(X))&&(!is.null(Z))) {
		## fitted values of Y knowing Z with respect to X
		if(is.factor(Z))
			Z<-model.matrix(~Z)
		tab<-lm.wfit(y=tab,x=Z,w=rw)$residuals
		if(is.factor(X))
			X<-model.matrix(~X)
		tab<-lm.wfit(tab,x=X,w=rw)$fitted.values
	}
	nl<-nrow(tab)
    nc<-ncol(tab)
	util<-matrix(0,nl,nl)
    index<-cbind(col(util)[col(util)<row(util)],row(util)[col(util)<row(util)])
	w<-as.numeric(rw[index[,1]]*rw[index[,2]])
	coords<-data.frame(coords)
	stopifnot(ncol(coords)==2)
	stopifnot(nrow(coords)==nl)
#	dist<-function(x) {
#        n<-nrow(x<-as.matrix(x))
#		d<-.C("R_distance",
#		  x=as.double(x),
#		  nr=n,
#		  nc=ncol(x),
#		  d=double(n*(n - 1)/2),
#		  diag=as.integer(FALSE),
#		  method=as.integer(1),
#		  p = as.double(2),
#		  DUP=FALSE,
#		  NAOK=TRUE,PACKAGE='diversity.R')$d
#	}

   # weight<-function(x,rw) {
   #     nlig<-nrow(x)
  #  	d<-matrix(0,nlig,nlig)
   # 	d.names<-row.names(x)
   #     index<-cbind(col(d)[col(d)<row(d)],row(d)[col(d)<row(d)])
   #     return(as.numeric(rw[index[,1]]*rw[index[,2]]))
   # }
   # w<-weight(df,rw)
    dw<-apply(tab,2,dist)^2*w
    dw<-apply(dw,1,divindex,cw)
    d<-dist(coords)
    if(is.character(breaks)) {
        if(breaks=="Sturges") {
            nint<-nclass.Sturges(d)
            lint<-(max(d)-min(d))/nint
            inter<-seq(0,nint*lint,lint)
        }
        else if(breaks=="Log") {
            nint<-nclass.Sturges(d)
			#inter<-lseq(min(d),max(d),ninter)
            inter<-seq(0,max(d)-min(d),length=nint)
            inter<-inter*log(inter+1)/log(inter[length(inter)]+1)+min(d)
        }
    }
    else inter<-as.vector(breaks)
    inter[1]<-inter[1]-inter[1]/10e9
    dfac<-as.factor(cut(d,inter,labels=FALSE))
    V<-apply(dw,1,function(x) tapply(x,dfac,sum))
    W<-tapply(w,dfac,sum)
    V<-apply(V,2,function(x) 0.5*x/W)
    res<-alist()
	res$Div<-Div
    if(test) {
    	res$nrepet<-nrepet
        res$alpha<-alpha
        mat1<-matrix(0,nrow=nrow(V),ncol=nrepet)
        mat2<-matrix(0,nrow=nrow(V),ncol=nrepet)
        mat3<-matrix(0,nrow=nrow(V),ncol=nrepet)
        class(d)<-"dist"
		attr(d,"Size")<-nl
		for(i in 1:nrepet) {
            alea<-.Internal(sample(nl,nl,FALSE,NULL))
            #attr(d,"Size")<-nr
            #dsim<-mat2dist(dist2mat(d)[alea,alea])
			#return(d)
			dsim<-as.dist(as.matrix(d)[alea,alea])
            dsimfac<-as.factor(cut(dsim,inter,labels=FALSE))
            Vsim<-apply(dw,1,function(x) tapply(x,dsimfac,sum))
            Wsim<-tapply(w,dsimfac,sum)
            Vsim<-apply(Vsim,2,function(x) 0.5*x/Wsim)
            mat1[,i]<-Vsim[,1]
            mat2[,i]<-Vsim[,2]
            mat3[,i]<-Vsim[,3]
        }
        mat1<-t(apply(mat1,1,sort,method="shell"))
        mat2<-t(apply(mat2,1,sort,method="shell"))
        mat3<-t(apply(mat3,1,sort,method="shell"))
        a1<-floor(alpha*(nrepet+1)/2)
        a2<-nrepet-a1
        if(a1==0) a1<-1
        res$richness<-data.frame(Dh=V[,1],ICn=mat1[,a1],ICp=mat1[,a2])
        res$Shannon<-data.frame(Dh=V[,2],ICn=mat2[,a1],ICp=mat2[,a2])
        res$Simpson<-data.frame(Dh=V[,3],ICn=mat3[,a1],ICp=mat3[,a2])
    }
    else {
    	res$richness<-data.frame(Dh=V[,1])
        res$Shannon<-data.frame(Dh=V[,2])
        res$Simpson<-data.frame(Dh=V[,3])
    }
    util<-inter
    for(i in 2:length(inter)) inter[i]<-(util[i]+util[i-1])/2
    res$h<-inter[-1]
    res$w<-W
    res$call<-match.call()
    class(res)<-c("div","variodis")
    return(res)
}

variodis.formula<-function(formula,data,coords,breaks="Sturges",test=TRUE,nrepet=999,alpha=0.01) {
    if (missing(data)) data<-parent.frame()
    fmla<-Cformula(formula,data)
    Y<-fmla$Y
    X<-fmla$X
    Z<-fmla$Z
    res<-variodis.default(Y,X,Z,coords,breaks,test,nrepet,alpha)
    res$call<-match.call()
    return(res)
}
