\encoding{latin1}
\name{anodiv}
\alias{anodiv}
\alias{anodiv.default}
\alias{anodiv.formula}
\alias{print.anodiv}
\alias{randtest.div.anodiv}
\alias{summary.div.anodiv}
\alias{summary.div.mlm}
\alias{print.summary.anodiv}
\title{ANOVA-like apportionments of species variance/diversity}
\description{
 'anodiv' is a generic function to perform ANOVA-like additive apportionments of species variance.
 
 'randtest.div.anodiv' is a function to perform Monte-Carlo tests of statistical significance from 'div anodiv' objects.
 
 'summary.div.anodiv' performs diversity apportionments and (optionally) related tests of statistical significance from 'div anodiv' objects.
}
\usage{
##default matrix interface
anodiv(Y,X=NULL,mod=NULL)
##formula interface
anodiv(formula,data)
##randomization tests
randtest(anodiv.object,nrepet=999,...)
summary(anodiv.object,nrepet=0,...)
}
\arguments{
\item{Y}{an abundance matrix with sites as rows and species as columns, or a factor of species names which can be coerced into a species occurrence table (see otab).}
\item{X}{an optional data frame contaning the explanatory factors and preferably provided by a call to 'anodiv.formula'.}
\item{mod}{an optional vector specifying the order of the explanatory factors in X and preferably provided by a call to 'anodiv.formula'.}
\item{formula}{a formula specifying the model (see details).}
\item{data}{a data frame or list in which the variables specified in the formula will be found. If missing, the variables are searched for in the standard way.}
\item{anodiv.object}{a object of class 'div anodiv'.} 
\item{nrepet}{an integer indicating the number of row permutations of the Monte Carlo test of statistical significance should be performed (see details). By default, no permutation test (nrepet=0).}
}
\details{
'anodiv' perfoms a multiple analysis of species variance for one-way, two-ways crossed and multi-ways hierarchical models. The only usfullness for the end-users of the matrix interface is to perform a one-way analysis from a single abundance matrix with sites as rows and species as columns, where the sites (rows) are modalities of the explanatory variable (see examples). The formula interface can be used in a standart way to specify multi-ways models (see formula{stats}):

 one-way: Y~X

 two-ways crossed with interaction:  Y~X1*X2 or Y~X1+X2+X1:X2 ; without interaction: Y~X1+X2

 two-ways nested: Y~X1/X2 (X2 nested within X1)

 multi-ways hierarchical: Y~X1/X2/X3 (X3 nested within X2 nested within X1) 

In these formulations, Y can be either an abundance matrix, a species occurrence table or a factor of species names which can be coerced into a species occurrence table (see otab). X contains only factors of the same length as Y (or as nrow(Y)).

'randtest.anodiv' performs randomization tests for one-way and two-ways nested models (tests for two-ways crossed models have not yet been implemented, while tests for multi-ways hierarchical models can be performed from multiple two-ways tests). In one-way models, all individual observations are randomized accross the levels of X (see testacross). In two-ways nested models, the higher ranked factor X1 is tested by randomizations of the nested levels accross the levels of X1, while the nested factor X2 is tested by randomizations of the individual observations accross the nested levels within the levels of X1 (see testwithin).

'summary.anodiv' performs an analysis of the species diversity in the richness, Shannon and Simpson metrics, according to model specifications attached to the 'anodiv.object'. If 'test=TRUE', the corresponding randomization tests of species variance and diversity are automatically launched (see examples).
}
\value{
'randtest.anodiv' returns a list of objects of class 'randtest'(so that pinting and plotting methods are available; see randtest{ade4}), one for each species and each term of the model. 

'anodiv' and 'summary.div.anodiv' return respectively a list of class 'div anodiv' and 'summary.anodiv' with the following components:
\item{$Y}{a factor of species names.}
\item{$X}{a data frame containing the explanatory factors.}
\item{$spw}{a vector of species weights.}
\item{$spvar}{a data frame of the species variances corresponding to terms of the model.}
\item{$df}{a vector of the degrees of freedom of the model terms.}
\item{$mod}{a vector specifying the order of interaction of the model terms (see terms.object{stats}), with a special attribute 'hierarchical' taking either the logical value 'TRUE' or 'FALSE'.}
\item{$call}{original call.}
\item{$div}{a data frame of the species diversity components corresponding to terms of the model.}
\item{$Fdiv}{a data frame of pseudo-F values correponding to the diversity components.}
\item{$ni}{a vector of species abundances.}
\item{$Fsp}{a data frame of pseudo-F values correponding to the variance components of each species.}
\item{$nrepet}{if 'test=TRUE', an integer corresponding to the number of row permutations used to perform the tests of statistical significance.}
\item{$pvaldiv}{if 'test=TRUE', a data frame containing the diversity p-values for each term of the model.}
\item{$pvalsp}{if 'test=TRUE', a data frame containing the species p-values for each term of the model.}
}
\references{Couteron, P. & Plissier, R. 2004. Additive apportionment of species diversity: twowards more sophisticated models and analyses. Oikos, 107(1): 215-221.}
\author{Raphael.Pelissier@ird.fr}
\seealso{\link{formula}, \link{terms.object}}
\examples{
data(CFI)
##Between-rows species variance
aod1<-anodiv(CFI$tab)
aod1
summary(aod1)
##randtest(aod1,nrepet=99)
## or with tests on both species variances and diversity components
summary(aod1,nrepet=99)

##One-way model
data(PSE)
aod2<-anodiv(Tfac~Sfac,PSE)
summary(aod2,nrepet=99)

##Two-ways crossed model
aod3<-anodiv(Tfac~Sfac*Qfac,PSE)
summary(aod3)

##Two-ways nested model
OCFI<-odf(CFI$tab,CFI$topo)
str(OCFI)
aod4<-anodiv(tab.col~CFI.topo/tab.row,OCFI)
summary(aod4,nrepet=99)

##multi-ways hierarchical model
##not to run. Too long.
#data(CP)
#str(CP)
#aod5<-anodiv(sp~comp/sol/dent/point,CP)
#summary(aod5)
}
