\encoding{latin1}
\name{ca.richness}
\alias{ca.richness}
\alias{ca.richness.default}
\alias{ca.richness.formula}
\title{multivariate ordination using species richness as a diversity metric (CA-richness strategy).}
\description{
'ca.richness' is a generic function to perform CA-richness strategy, i.e. a form of Correspondence Analysis, optionally partial and/or constrained with respect to Instrumental Variables, whose metric is consistent with species richness as a measure of diversity. 
}
\usage{
##default matrix interface
ca.richness(Y,X=NULL,Z=NULL,test=TRUE,nrepet=999)
##formula interface
ca.richness(formula,data,test=TRUE,nrepet=999)
}
\arguments{
   \item{Y}{an abundance matrix with sites as rows and species as columns, or a factor of species names which can be coerced into a species occurrence table (see otab).}
  \item{X}{a optional constraining matrix of Instrumental Variables, or a factor partitioning the rows of Y into classes (see details).}
   \item{Z}{a optional conditioning matrix of Instrumental Variables, or a factor partitioning the rows of Y into classes (see details).}
   \item{formula}{specific model formula where the left hand side gives the dependent variables (Y), right hand side gives the constraining variables (X), and conditioning variables (Z) can be given within a special function 'Condition' (see details).}
  \item{data}{a data frame or list in which the variables specified in the formula will be found. If missing, the variables are searched for in the standard way.}
 \item{test}{a logical value indicating whether a Monte Carlo test of statistical significance should be performed (see randtest.div).}
  \item{nrepet}{if 'test=TRUE', an integer indicating the number of row permutations of the Monte Carlo test.}
}
\details{ In matrix interface, 'Y' is typically a site-by-species abundance matrix, but may be a factor of species names, in which case it is automatically converted into a species occurrence table, i.e. a complete binary matrix with as many rows as individuals (or occurrences) and as many columns as species (see otab). If both other matrices are omitted, the function performs a simple Correspondence Analysis (see dudi.coa). If 'X' is supplied, it is used to constrain the ordination, resulting either in a Correspondence Analysis on Instrumental Variables (CAIV) when 'X' is a matrix of independent variables (see pcaiv), or a between-analysis when 'X' is a factor (see between). If 'Z' is supplied, its effects are removed, so that the residuals are either submitted to ordinary CA when 'X' is not supplied (see pcaivortho and within) or CAIV when both 'X' and 'Z' are supplied (partial-CAIV).

In formula interface, the model can be defined using a specific model 'formula' similar to the one used in cca{vegan}. The left hand side defines the 'Y' dependent variables. The right hand side defines the constraining 'X' variables and can include a special term 'Condition' for conditioning variables 'Z', so that 'ca.richness(Y~X+Condition(Z))' is equivalent to 'ca.richness(Y,X,Z)' (see examples).
}
\value{
  returns a list of class 'div' and 'dudi' and of type 'between', 'pcaiv', 'within' or 'pcaivortho' according to the analysis performed, with the following additional components:
\item{divopt}{1 indicating that the diversity metric used is species richness.}
\item{Dtot}{the total diversity of 'Y' in richness metric.}
\item{pvalue}{if 'test=TRUE', statistical significance probability of the permutation test.}
\item{nrepet}{if 'test=TRUE', the number of row permutations used to perform the test.}
}
\note{
the permutation tests performed when 'test=TRUE' are different according to the type of the object returned by 'ca.richness' (see randtest.div).}
\references{Couteron, P., Plissier, R., Mapaga, D., Molino, J.-F. & Teillier, L. 2003. Drawing ecological insights from a management-oriented forest inventory in French Guiana. Forest Ecology and Management, 172: 89-108.

Plissier, R., Couteron, P., Dray, S. & Sabatier, D. 2003. Consitency between ordination techniques and diversity measurements: two strategies for species occurrence data. Ecology, 84 (1): 242-251.}
\author{Raphael.Pelissier@ird.fr}
\seealso{\link{nsca.simpson}, \link{cwca.shannon}, \link{dudi.div}, \link{summary.div}, \link{plot.div}, \link{between}, \link{within}, \link{pcaiv}, \link{pcaivortho}}
\examples{
data(CFI)
##simple CA
ca<-ca.richness(CFI$tab) #Select the number of axes:
2
summary(ca)
plot(ca)

##CAIV with respect to topo variables
ca.topo<-ca.richness(CFI$tab~CFI$topo) #Select the number of axes:
2
summary(ca.topo)
plot(ca.topo)

##residual-CAIV once removed the effects of dbh
ca.Sdbh<-ca.richness(CFI$tab~Condition(CFI$dbh)) #Select the number of axes:
2
summary(ca.Sdbh)
plot(ca.Sdbh)

##partial-CAIV with respect to topo variables once removed the effects of dbh
ca.topoSdbh<-ca.richness(CFI$tab~CFI$topo+Condition(CFI$dbh)) #Select the number of axes:
2
summary(ca.topoSdbh)
plot(ca.topoSdbh)
}
