\encoding{latin1}
\name{cwca.shannon}
\alias{cwca.shannon}
\alias{cwca.shannon.default}
\alias{cwca.shannon.formula}
\title{multivariate ordination using shannon diversity metric.}
\description{
'cwca.shannon' is a generic function to perform a form of (Column Weighted) Correspondence Analysis, optionally partial and/or constrained with respect to Instrumental Variables, whose metric is consistent with Shannon diversity. 
}
\usage{
##default matrix interface
cwca.shannon(Y,X=NULL,Z=NULL,test=TRUE,nrepet=999)
##formula interface
cwca.shannon(formula,data,test=TRUE,nrepet=999)
}
\arguments{
   \item{Y}{an abundance matrix with sites as rows and species as columns, or a factor of species names which can be coerced into a species occurrence table (see otab).}
  \item{X}{a optional constraining matrix of Instrumental Variables, or a factor partitioning the rows of Y into classes (see details).}
   \item{Z}{a optional conditioning matrix of Instrumental Variables, or a factor partitioning the rows of Y into classes (see details).}
   \item{formula}{specific model formula where the left hand side gives the dependent variables (Y), right hand side gives the constraining variables (X), and conditioning variables (Z) can be given within a special function 'Condition' (see details).}
  \item{data}{a data frame or list in which the variables specified in the formula will be found. If missing, the variables are searched for in the standard way.}
 \item{test}{a logical value indicating whether a Monte Carlo test of statistical significance should be performed (see randtest.div).}
  \item{nrepet}{if 'test=TRUE', an integer indicating the number of row permutations of the Monte Carlo test.}
}
\details{ In matrix interface, 'Y' is typically a site-by-species abundance matrix, but may be a factor of species names, in which case it is automatically converted into a species occurrence table, i.e. a complete binary matrix with as many rows as individuals (or occurrences) and as many columns as species (see otab). If both other matrices are omitted, the function performs a simple (Column Weighted) Correspondence Analysis consistent with Shannon diversity. If 'X' is supplied, it is used to constrain the ordination, resulting either in a (Column Weighted) Correspondence Analysis on Instrumental Variables when 'X' is a matrix of independent variables (see pcaiv), or a between-analysis when 'X' is a factor (see between). If 'Z' is supplied, its effects are removed, so that the residuals are either submitted to simple (Column Weighted) CA when 'X' is not supplied (see pcaivortho and within) or (Column Weighted) CAIV when both 'X' and 'Z' are supplied (partial-analysis).

In formula interface, the model can be defined using a specific model 'formula' similar to the one used in cca{vegan}. The left hand side defines the 'Y' dependent variables. The right hand side defines the constraining 'X' variables and can include a special term 'Condition' for conditioning variables 'Z', so that 'cwca.shannon(Y~X+Condition(Z))' is equivalent to 'cwca.shannon(Y,X,Z)' (see examples).
}
\value{
returns a list of class 'div' and 'dudi' and of type 'between', 'pcaiv', 'within' or 'pcaivortho' according to the analysis performed, with the following additional components:
\item{divopt}{2 indicating that the diversity metric used is Shannon diversity.}
\item{Dtot}{the total diversity of 'Y' in Shannon metric.}
\item{pvalue}{if 'test=TRUE', statistical significance probability of the permutation test.}
\item{nrepet}{if 'test=TRUE', the number of row permutations used to perform the test.}
}
\note{
the permutation tests performed when 'test=TRUE' are different according to the type of the object returned by 'cwca.shannon' (see randtest.div).}
\references{Couteron, P., Plissier, R., Mapaga, D., Molino, J.-F. & Teillier, L. 2003. Drawing ecological insights from a management-oriented forest inventory in French Guiana. Forest Ecology and Management, 172: 89-108.

Plissier, R., Couteron, P., Dray, S. & Sabatier, D. 2003. Consitency between ordination techniques and diversity measurements: two strategies for species occurrence data. Ecology, 84 (1): 242-251.}
\author{Raphael.Pelissier@ird.fr}
\seealso{\link{nsca.simpson}, \link{ca.richness}, \link{dudi.div}, \link{summary.div}, \link{plot.div}, \link{between}, \link{within}, \link{pcaiv}, \link{pcaivortho}}
\examples{
data(CFI)
##simple (Column Weighted) CA
cwca<-cwca.shannon(CFI$tab) #Select the number of axes:
2
summary(cwca)
plot(cwca)

##(Column Weighted) CAIV with respect to topo variables
cwca.topo<-cwca.shannon(CFI$tab~CFI$topo) #Select the number of axes:
2
summary(cwca.topo)
plot(cwca.topo)

##residual-(Column Weighted)CAIV once removed the effects of dbh
cwca.Sdbh<-cwca.shannon(CFI$tab~Condition(CFI$dbh)) #Select the number of axes:
2
summary(cwca.Sdbh)
plot(cwca.Sdbh)

##partial-(Column Weighted)CAIV with respect to topo variables once removed the effects of dbh
cwca.topoSdbh<-cwca.shannon(CFI$tab~CFI$topo+Condition(CFI$dbh)) #Select the number of axes:
2
summary(cwca.topoSdbh)
plot(cwca.topoSdbh)
}
