\encoding{latin1}
\name{dissim}
\alias{dissim}
\alias{dissim.default}
\alias{dissim.formula}
\alias{print.dissim}
\alias{summary.dissim}
\title{species contrast and dissimilarity matrices}
\description{
 'dissim' computes species contrasts and dissimilarity matrices using Euclidean distances and species weights that rely on three common diversity measurements: species richness, Simpson diversity and Shannon information.
}
\usage{
##default matrix interface
dissim(Y,X=NULL,Z=NULL)
##formula interface
dissim(formula,data)
summary(dissim.object)
}

\arguments{
  \item{Y}{a abundance matrix with sites as rows and species as columns, or a table of species occurrences (see otab).}
  \item{X}{a optional constraining matrix of Instrumental Variables, or a factor partitioning the rows of Y into classes (see details).}
  \item{Z}{a optional conditioning matrix of Instrumental Variables, or a factor partitioning the rows of Y into classes (see details).}
  \item{formula}{specific model formula where the left hand side gives the dependent variables (Y), right hand side gives the constraining variables (X), and conditioning variables (Z) can be given within a special function 'Condition' (see details).}
  \item{data}{a data frame or list in which the variables specified in the formula will be found. If missing, the variables are searched for in the standard way.}
  \item{dissim.object}{an object of class 'div dissim'.}
}
\details{ In matrix interface, 'Y' is typically a site-by-species abundance matrix, but may be a factor of species names, in which case it is automatically converted into a species occurrence table, i.e. a complete binary matrix with as many rows as individuals (or occurrences) and as many columns as species (see otab). If both other matrices are omitted, the function computes dissimilarities among the rows of Y. If 'X' is supplied, dissimilarities are computed among the rows of Yest, i.e. table Y fitted with respect to X, a matrix or factor of independent variables. If 'Z' is supplied, its effect is removed, so that the function computes dissimilarities either between the rows of Yres, i.e. the residuals of Y fitted with respect to Z ('X' is not supplied) or between the rows of Yres fitted with respect to X (effect of Z removed).

In formula interface, the model can be defined using a specific model 'formula' similar to the one used in cca{vegan}. The left hand side defines the 'Y' dependent variables. The right hand side defines the constraining 'X' variables and can include a special term 'Condition' for conditioning variables 'Z', so that 'dissim(Y~X+Condition(Z))' is equivalent to 'dissim(Y,X,Z)' (see examples).
}
\value{
  'dissim' returns an object of class 'div dissim', i.e. a list with the following components:
  \item{delta}{a data frame of the lower triangles of the contrast matrices between the rows of 'Y' stored by species (columns), so that it has as many columns as ncol(Y) and, given n=nrow(Y), as many rows as n*(n-1)/2.}
  \item{dissim}{a data frame of the lower triangles of the dissimilarity matrices between the rows of 'Y', respectively in the richness, Shannon and Simpson metrics (3 columns and n*(n-1)/2 rows).}
  \item{index}{a data frame of indices, i.e. pair of numbers corresponding to the rows of 'Y' between which were computed the values of 'delta' and 'dissim' (2 columns and n*(n-1)/2 rows).}
  \item{weights}{a vector of the contrast weights of length n*(n-1)/2.}
  
  'summary.div.dissim' returns an object of class 'summary.dissim', i.e. a data.frame of diversity components corresponding to terms of the model.
 }
\references{Couteron, P. & Plissier, R. 2004. Additive apportioning of species diversity: towards more sophisticated models and analyses. Oikos, 107(1): 215-221.
}
\author{Raphael.Pelissier@ird.fr}
\seealso{\link{otab},\link{summary.div},\link{variodis}}
\examples{
data(CFI)
##compute between-rows dissimilarity of 'CFI$tab' 
dtab<-dissim(CFI$tab)
summary(dtab)
dtab

##compute between-rows dissimilarity of 'CFI$tab' predicted by 'CFI$topo'  
dtopo<-dissim(CFI$tab~CFI$topo)
summary(dtopo)
dtopo

##compute between-rows dissimilarity of 'CFI$tab' once removed the effect of 'CFI$topo' 
dtopo.res<-dissim(CFI$tab~Condition(CFI$topo))
summary(dtopo.res)
dtopo.res

##compute between-rows dissimilarity from of 'CFI$tab' predicted by CFI$topo, once removed the effect of 'topo2', i.e. within the levels of 'topo2'
topo2<-CFI$topo
levels(topo2)[1:7]<-"uplands"
levels(topo2)[-1]<-"bottomlands"
dtopo.within<-dissim(CFI$tab~CFI$topo+Condition(topo2))
}
