\encoding{latin1}
\name{dudi.div}
\alias{dudi.div}
\title{multivariate ordination using diversity metrics}
\description{
'dudi.div' performs a multivariate ordination with three options of species weighthing that rely on three common diversity measurements: species richness, Simpson diversity and Shannon information.
}
\usage{
dudi.div(Ytab, scanopt = TRUE, opt = 1, scannf = TRUE, nf = 2, call = match.call(), full = FALSE)
}
\arguments{
\item{Ytab}{an abundance matrix with sites as rows and species as columns.}
\item{scanopt}{a logical value indicating whether a user interface to choose one of the three options of diversity measurement should be displayed.}
\item{opt}{if 'scanopt=FALSE', an integer indicating the diversity measurement to be used (1=species richness; 2=Shannon information; 3=Simpson diversity).}
\item{scannf}{a logical value indicating whether the eigenvalues bar plot should be displayed.}
\item{nf}{if 'scannf=FALSE', an integer indicating the number of axes to be saved.}
\item{call}{'match.call()' by default.}
\item{full}{a logical value indicating whether all non null eigenvalues should be saved.}
}
\value{returns a list of class 'div' and 'dudi' (see dudi) with the following additional components:
\item{divopt}{a integer value indicating diversity metric selected (1=species richness; 2=Shannon information; 3=Simpson diversity).}
\item{Dtot}{the total diversity of 'Ytab' in the metric selected.}
}
\references{Plissier, R., Couteron, P., Dray, S. & Sabatier, D. 2003. Consitency between ordination techniques and diversity measurements: two strategies for species occurrence data. Ecology, 84 (1): 242-2.}
\author{Raphael.Pelissier@ird.fr}
\note{'dudi.div' returns an object of class 'div' and 'dudi', therefore suitable for use with many standard functions of package 'ade4' (see example). }
\seealso{\link{dudi}, \link{summary.div}, \link{plot.div}, \link{randtest.div}}
\examples{
data(CFI)
## richness metric
rich<-dudi.div(CFI$tab,scanopt=FALSE,opt=1,scannf=FALSE)
summary(rich)
plot(rich)
## Shannon metric
shan<-dudi.div(CFI$tab,scanopt=FALSE,opt=2,scannf=FALSE)
summary(shan)
plot(shan)
## Simpson metric
simp<-dudi.div(CFI$tab,scanopt=FALSE,opt=3,scannf=FALSE)
summary(simp)
plot(simp)

## Example of between-analysis in Simpson metric using bca{ade4}
simp.topo<-bca(simp,CFI$topo,scannf=FALSE)
simp.topo
plot(simp.topo)

## Example of PCAIV in richness metric using pcaiv{ade4}
rich.dbh<-pcaiv(rich,CFI$dbh,scannf=FALSE)
rich.dbh
plot(rich.dbh)
}