\encoding{latin1}
\name{kmsov.rtest}
\alias{kmsov.rtest}
\alias{kmsov}
\alias{msov}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Variograms and co-variograms of ordination axes}
\description{
'kmsov.rtest' computes variograms and co-variograms of ordination axes and performs non-paramtric tests of statistical significance by row permutations.
}
\usage{
kmsov.rtest(dudi,knb,ax,fac=NULL,nrepet=99)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{dudi}{an object of class 'dudi{ade4}', including those of subclass 'div' (see details).}
  \item{knb}{an object of class 'knb' (see details).}
  \item{ax}{a vector of integer giving the ranks (column numbers) of the factorial axes to be studied.}
  \item{fac}{a factor to be specified when permutation tests are performed on residual ordination axes (see details). NULL is the default value when working on initial tables.}
  \item{nrepet}{a interger indicating the number of permutations for the tests.} 
}
\details{
Objects of class 'c(div,dudi)' consistent with the most common diversity indices are returned by functions \link{ca.richness}, \link{nsca.simpson} and \link{cwca.shannon}.
Objects of class 'knb' give the list of neighbours considered within each distance class of the variogram. It can be obtained from \eqn{(x,y)} co-ordinates by function \link{bornes2knb}.
'fac' has to be specified for indicating that randomizations have to be made within the levels of 'fac' when variograms are computed on residual ordination axes.
Otherwise, complete randomizations are used for variograms computed on inital data.
}
\value{
An half matrix of \eqn{k} variograms and \eqn{k(k-1)/2} co-variograms, with 95\% confidence intervals when \eqn{nrepet>0}.
}
\references{Couteron, P. & Ollier, S. 2005. A generalized, variogram-based framework for mulstiscale ordination. Ecology, 86(4): 828-834.}
\author{sebastien.ollier@u-psud.fr}
\seealso{\link{bornes2knb}, \link{ca.richness}, \link{nsca.simpson}, \link{cwca.shannon}, \link{dudi.div}, \link{spadis}}
\examples{
data(CFI)
##computes the neighbouring matrices defining the distance classes of the variograms
cfi.knb<-bornes2knb(CFI$xy,c(0.38,0.45,0.80,1.20,2.00,3.00,4.00,5.00,7.00,9.00,13.00))

##perform initial CA of CFI$tab
cfi.ca<-ca.richness(CFI$tab,test=FALSE) #Select the number of axes: 
3
##computes the variograms and co-variograms of CA axes 2 and 3
cfi.ca.rtest<-kmsov.rtest(cfi.ca,cfi.knb,ax=c(2,3),nrepet=0)
plot(cfi.ca.rtest)
##This can take a few minutes with the defaults \eqn{nrepet=99} permutations
##cfi.ca.rtest<-kmsov.rtest(cfi.ca,cfi.knb,ax=c(2,3))
##plot(cfi.ca.rtest)

##performs residual CAIV, i.e. once removed the effects of variable CFI$topo
cfi.caStopo<-ca.richness(CFI$tab~Condition(CFI$topo),test=FALSE) #Select the number of axes:
3
##computes the variograms and co-variograms of residual axes 2 and 3
cfi.caStopo.rtest<-kmsov.rtest(cfi.caStopo,cfi.knb,ax=c(2,3),fac=CFI$topo,nrepet=0)
plot(cfi.caStopo.rtest)
##This can take a few minutes with the defaults \eqn{nrepet=99} permutations
##cfi.caStopo.rtest<-kmsov.rtest(cfi.caStopo,cfi.knb,ax=c(2,3),fac=CFI$topo)
##plot(cfi.caStopo.rtest)
}
