\encoding{latin1}
\name{odf}
\alias{odf}
\alias{as.odf}
\alias{is.odf}
\alias{summary.odf}
\title{Occurrence data frame creation}
\description{
'odf' creates an occurrence data frame, i.e. a data frame with as many rows as individuals (or occurrences) and factors or vectors as columns.
}
\usage{
odf(tab, ...)
as.odf(..., sp.fac=1)
is.odf(x)
summary.odf(x, sp.fac=1)
}
\arguments{
  \item{tab}{an abundance table with samples as rows and species as columns.}
  \item{x}{a data.frame with individuals (or occurrences) as rows and factors or vectors as columns.}
\item{sp.fac}{a numeric value indicating which column contains the species information (the first column by default.}
\item{\dots}{further objects to be added to (or coerced into) an occurrence data frame.}
}
\value{
  'odf' returns an object of class 'odf data.frame' with as many rows as 'sum(tab)' and 2 columns corresponding to the classifying factors of the colums and rows of tab. A single column is returned if 'tab' is a species occurrence table (see 'otab()'). As many columns as the number of arguments in '...' are added to the occurrence data frame.
  
  'as.odf' returns an object of class 'odf data.frame' with as many rows as the arguments in '...' and as many columns as the number of arguments in '...'. Argument 'sp.fac' can be adjusted if the species information is not contained in the first argument.
  
  'is.odf' returns TRUE if 'x' is of class 'odf'.
  
  'summary.odf' is the 'summary' method for objects of class 'odf', which performs individual species variances and basic diversity indices from column 'sp.fac' of 'x' (the first by default).  
}
\references{
Couteron, P. & Plissier, R. 2004. Additive apportionment of species diversity: twowards more sophisticated models and analyses. Oikos, 107(1): 215-221.

Plissier, R., Couteron, P., Dray, S. & Sabatier, D. 2003. Consitency between ordination techniques and diversity measurements: two strategies for species occurrence data. Ecology, 84 (1): 242-251.}
\author{Raphael.Pelissier@ird.fr}
\seealso{\code{\link{otab}}}
\examples{
data(CFI)
str(CFI)
CFI.odf<-odf(CFI$tab,CFI$topo)
str(CFI.odf)
is.odf(CFI.odf) #TRUE
summary(CFI.odf)
}