\encoding{latin1}
\name{randtest.div}
\alias{randtest.div}
\title{Monte Carlo tests for objects of class 'div'.}
\description{
Performs randomization Monte Carlo tests of explained diversity from 'div dudi' and 'div anodiv' objects. The function calls particular sub-methods according to the sub-class of the 'div' object (see details).
}
\usage{
randtest(div.object, nrepet = 999, ...)
}
\arguments{
  \item{div.object}{a object of class 'div dudi' or 'div anodiv'.}
  \item{nrepet}{the number of permutations used to perform the test.}
  \item{\dots}{further arguments passed to or from other methods.}
}
\details{
    When 'div.object' is of class 'div dudi' all indivdiuals are randomized accross the rows of the original data table (total radomization).
    When 'div.object' is of class 'div dudi between' the rows of the original data table are randomized accross the levels of an external categorical variable.
    When 'div.object' is of class 'div dudi pcaiv' the rows of the original data table are randomized before re-computing the multiple linear regressions.
  When 'div.object' is of class 'div anodiv' the randomization method depends on specifications of the model (see anodiv).
 }
\value{'randtest.div' returns an object of class 'randtest', so that printing and plotting functions are available from package:ade4.
  }
\author{Raphael.Pelissier@ird.fr}
\seealso{\link{randtest}, \link{print.randtest}, \link{plot.randtest}, \link{randtest.between}, \link{rtest.pcaiv}, \link{randtest.div.anodiv}}
\examples{
##'div dudi' objects
data(PSE)
tab<-as.data.frame(unclass(table(PSE$Sfac,PSE$Tfac)))
div1<-dudi.div(tab,scanopt=FALSE,scannf=FALSE)
test<-randtest(div1)
test
plot(test)

##'div anodiv' objects
aod<-anodiv(Tfac~Sfac,PSE)
test<-randtest(aod,nrepet=99)
test
#plot results for first sepcies
plot(test[[1]],main=names(test)[1])
}
