\encoding{latin1}
\name{spadis}
\alias{spadis}
\alias{print.spadis}
\title{Distance-related apportionment of species variance/diversity.
}
\description{
'spadis' performs ANOVA-like range-related additive apportionment of species variance/diversity from contrast/dissimilarity matrices.
}
\usage{
spadis(formula, data, range = c("min", "max"), test = TRUE, nrepet = 999)
}
\arguments{
\item{formula}{a formula specifying the model (see details).}
\item{data}{a data frame or list in which the variables specified in the formula will be found. If missing, the variables are searched for in the standard way.}
 \item{range}{a vector of length 2 indicating the range of distance to apportion species diversity. By default, "min" and "max" correspond to minimum and maximum geographic distance between two sites.}
\item{test}{a logical value indicating whether row permutation test should be performed.}
\item{nrepet}{if test is TRUE, an integer indicating the number of distance permutations to be performed.}
}
\details{
'spadis' perfoms simple range-related apportionment of species variance/diversity
     (one-way model) as well as nested range-related apportionment within the classes of an explanatory variable (two-ways nested model). The model is defined using a specific
     model 'formula': the left hand side indicates the dependent site-by-species abundance matrix (Y); the right hand side contains the xy sites coordinates matrix (XY) that defines, along with argument 'range', the explanatory distance-related variable (i.e. a range of site to site distances). The right hand side can also include a higher ranked explanatory factor (X), so that the range-related apportionment is performed within the classes of X (nested model). Therefore, the only allowed formulas are:
     
      one-way: Y~XY 
     
      two-ways nested: Y~X/XY 
}
\value{
  'spadis' returns an object of class 'spadis', so that 'print.spadis' is the corresponding printing method.  An object of class 'spadis' is a list of with the following components:
  \item{$mod}{a vector specifying the order of interaction of the model terms (see terms.object{stats}).}
   \item{$range}{a vector of length two giving the range of site to site distances used as the explanatory distance-related variable.}
   \item{$dis}{a data frame of the species diversity components corresponding to terms of the model.}
   \item{$spdis}{a data frame of the species variances corresponding to terms of the model.}
   \item{$call}{original call.}
     }
\references{Couteron, P. & Plissier, R. 2004. Additive apportioning of species diversity: towards more sophisticated models and analyses. Oikos, 107(1): 215-221.}
\author{Raphael.Pelissier@ird.fr}
\note{'spadis' is a direct transcription of an old function, which will be soon designed in a different format more consistent with the 'anodiv' function.}
\seealso{\link{anodiv}, \link{terms.object}}
\examples{
data(CFI)
##perform a simple (one-way) short-range (<=1 km) apportionment of species diversity
##dist1<-spadis(tab~xy,CFI,c("min",1)) # allowing randomization tests will take a little time
dist1<-spadis(tab~xy,CFI,c("min",1),test=FALSE)
dist1

##perform a nested long-range (>5 km) apportionment of species diversity
##dist2<-spadis(tab~xy/topo,CFI,c(5,"max")) # allowing randomization tests will take a little time
dist2<-spadis(tab~xy/topo,CFI,c(5,"max"),test=FALSE)
dist2
}