\encoding{latin1}
\name{summary.div}
\alias{summary.div}
\title{summary method for objects of class 'div' and objects of class 'mlm'.}
\description{'summary.div' is a method used to compute and print summary results for objects of class 'div dudi' and 'div anodiv' by
     invoking particular sub-methods which depend on the sub-class of the 'div' object.
     It also allows expressing standard 'mlm' objects computed by aov{stats} or lm{stats} like 'anodiv' objects. 
}
\usage{
#for 'div dudi', 'mlm', 'dissim' and 'variodis' objects
summary(object, ...)
#for 'div anodiv' objects
summary(object,nrepet=0, ...)
}
\arguments{
  \item{object}{an object of class 'div dudi', 'div anodiv' 'mlm', 'div dissim' or 'div variodis'.}
  \item{nrepet}{an integer indicating the number of row permutations of the Monte Carlo test of statistical significance (only for 'anodiv' objects). By default, no permutation test performed (nrepet=0).}
  \item{...}{additional arguments affecting the summary produced.}
}
\value{
  If 'object' is of class 'div dudi', 'summary.div' returns an object of class 'summary.dudiv' with the following components:
  \item{$divopt}{a integer indicating the diversity metric (1=species richness; 2=Shannon information; 3=Simpson diversity).}
  \item{$call}{original call.}
  \item{$Dtot}{total species diversity of the community.}
  \item{$Dfit}{diversity explained by the analysis, i.e. the sum of all eigenvalues.}
  \item{$Dres}{residual diversity, i.e. dudiv$Dtot-dudiv$Dfit.}
  \item{$Drat}{ratio of explained diversity, i.e. dudiv$Dfit/dudiv$Dtot.}
  \item{$pvalue}{statistical significance probability of the permutation test.}
  \item{$nrepet}{the number of row permutations used to perform the test.}
  
   If 'object' is of class 'div anodiv', 'summary.div' returns an object of class 'summary.anodiv' (see anodiv).
   
   If 'object' is of class 'mlm' computed from aov{stats} or lm{stats}, 'summary.div' returns an object of class 'summary.anodiv' (see example).
   
   If 'object' is of class 'div dissim' or 'div variodis', 'summary.div' returns an object of class 'summary.dissim' and 'summary.variodis', repectively (see dissim and anodiv).
}
\note{'summary.div' prints directely the results in a convenient form, but can also be assigned.
}
\references{Plissier, R., Couteron, P., Dray, S. & Sabatier, D. 2003.
     Consitency between ordination techniques and diversity
     measurements: two strategies for species occurrence data. Ecology,
     84 (1): 242-251.
     Couteron, P. & Plissier, R. 2004. Additive apportionment of
     species diversity: twowards more sophisticated models and
     analyses. Oikos, 107(1): 215-221.
	 Plissier, R. & Couteron, P. 2007. An operational, additive framework for species diversity partitioning and beta-diversity analysis. Journal of Ecology, 95: 294-300.
	 }
\author{Raphael.Pelissier@ird.fr}
\seealso{\link{dudi.div}, \link{ca.richness}, \link{cwca.shannon}, \link{nsca.simpson}, \link{anodiv}, \link{aov}, \link{lm}, \link{dissim}, \link{variodis}}
\examples{
##'div dudi' objects
data(CFI)
div1<-dudi.div(CFI$tab,scanopt=FALSE,scannf=FALSE)
summary(div1)
smry<-summary(div1)
str(smry)

div2<-ca.richness(tab~topo,CFI,test=FALSE) #Select the number of axes:
2
summary(div2)

##'div anodiv' objects
data(PSE)
aod1<-anodiv(Tfac~Sfac,PSE)
summary(aod1)
## or with tests on both species variances and diversity components
summary(aod1,nrepet=99)

##'mlm' objects
PSE.otab<-otab(PSE$Tfac)
aod2<-aov(PSE.otab~PSE$Sfac)
summary.div(aod2) #id summary(aod1)
##quantitative explanatory variable
var<-as.integer(PSE$Sfac) #converting a factor to an ordinal variable
lm1<-lm(PSE.otab~var)
summary.div(lm1)
}