\encoding{latin1}
\name{suprow.div}
\alias{suprow.div}
\title{performs projections of supplementary rows}
\description{
'suprow.div' performs projections of supplementary rows for class 'div' objects.
}
\usage{
suprow.div(x,Xsup, ...)
}
\arguments{
\item{x}{an object of class 'div' and 'dudi'.}
\item{Xsup}{an array with the supplementary rows (Xsup and x$tab have the same column number).}
\item{...}{further arguments passed to or from other methods.}
}
\details{suprow.div is the suprow{ade4} method for class 'div' objetcs (see suprow{ade4}), i.e. the transformed column vectors of Xsup are projected onto the principal components of dudi with respect to its associated column (species) weights.}
\value{returns a list of two components:
\item{tabsup}{the transformed supplementary table.}
\item{lisup}{coordinates of the supplementary projections on each axis.}
}
\references{Plissier, R., Couteron, P., Dray, S. & Sabatier, D. 2003. Consitency between ordination techniques and diversity measurements: two strategies for species occurrence data. Ecology, 84 (1): 242-251.}
\author{Raphael.Pelissier@ird.fr}
\seealso{\link{suprow}, \link{dudi.div}, \link{ca.richness}, \link{nsca.simpson}, \link{cwca.shannon}}
\examples{
data(CFI)
## richness metric
rich<-dudi.div(CFI$tab,scanopt=FALSE,opt=1,scannf=FALSE)
suprich<-suprow(rich,CFI$tab[1:10,])
plot(rich$li[,1],rich$li[,2])
points(suprich$lisup[,1],suprich$lisup[,2],col="red")
## Shannon metric
shan<-dudi.div(CFI$tab,scanopt=FALSE,opt=2,scannf=FALSE)
supshan<-suprow(shan,CFI$tab[1:10,])
plot(shan$li[,1],shan$li[,2])
points(supshan$lisup[,1],supshan$lisup[,2],col="red")
## Simpson metric
simp<-dudi.div(CFI$tab,scanopt=FALSE,opt=3,scannf=FALSE)
supsimp<-suprow(simp,CFI$tab[1:10,])
plot(simp$li[,1],simp$li[,2])
points(supsimp$lisup[,1],supsimp$lisup[,2],col="red")
}