#include <math.h>
#include <time.h>
#include <string.h>
#include <stdlib.h>
#include "diversity.h"
#include "diversitysub.h"
#include "adesub.h"
#include <R.h>

/************************************************************************/
/*Returns in vector res:						*/
/****first nc1 values=observed by-column variances between rows of 	*/
/*redtab which crosses lvec1 with cvec1. redtab has size nl1*nc1 and 	*/
/*sums to (nt1).							*/
/****next np1*nc1 values=np1 vectors of by-column variances between rows*/
/*of redtab after randomization of lvec2 across lvec1 levels.	 	*/
/************************************************************************/
void testacross1(int *cvec1,int *nc1,int *lvec1,int *nl1,int *lvec2,int *nl2,int *nt1,int *np1, double *res) {	
    double **tab,*var,**redtab;
    int i,j,k;
    int *numero,*strata;
    taballoc(&tab,*nl2,*nc1);
    taballoc(&redtab,*nl1,*nc1);
    vecalloc(&var,*nc1);
    vecintalloc(&strata,*nl2);
    vecintalloc(&numero,*nl2);
    
    //Creates the cross-classifying tab from lvec2 and cvec1
    //Records the correponding lvec1 codes in fac
    for(i=0;i<*nt1;i++) {
        tab[lvec2[i]][cvec1[i]]+=1;
        strata[lvec2[i]]=lvec1[i];
    }
    
    //Aggregates the rows of tab in redtab according to fac
    for(i=1;i<=*nl2;i++)
        for(j=1;j<=*nc1;j++)
            redtab[strata[i]][j]+=tab[i][j];
    
    //Computes initial by-column variances between the rows of redtab
    varinter(redtab,*nl1,*nc1,*nt1,var);

    //Writes the C variable var within the R variable res
    for (j=1;j<=*nc1;j++)
            res[j-1]=var[j];
     
    //Creates cross-classifying redtab from tab randomized by rows
    //Computes by-column variances between the rows of redtab
    //Writes the C variable var within the R variable res                   
    for (k=1; k<=*np1; k++) {
        getpermutation(numero,k);
        taballoc(&redtab,*nl1,*nc1);
        for(i=1;i<=*nl2;i++)
            for(j=1;j<=*nc1;j++)
                redtab[strata[i]][j]+=tab[numero[i]][j];
        vecalloc(&var,*nc1);
        varinter(redtab,*nl1,*nc1,*nt1,var);
        for (j=1;j<=*nc1;j++)
            res[k*(*nc1)+(j-1)]=var[j];
  }
  
  freetab(tab);
  freetab(redtab);
  freeintvec(numero);
  freevec(var);
  freeintvec(strata);
}
/****************************************************/
/*idem testacross1 but returns only pvalues pvalues*/
/***************************************************/ 
void testacross2(int *cvec1,int *nc1,int *lvec1,int *nl1,int *lvec2,int *nl2,int *nt1,int *np1, double *res) {	
    double **tab,*varsim,**redtab,*cw,*varobs,*divobs,*dsim;
    int i,j,k;
    int *numero,*strata;
    taballoc(&tab,*nl2,*nc1);
    taballoc(&redtab,*nl1,*nc1);
    vecintalloc(&strata,*nl2);
	vecalloc(&cw,*nc1);
	vecalloc(&varobs,*nc1);
	vecalloc(&divobs,3);
	
    //Creates the cross-classifying tab from lvec2 and cvec1
    //Records the correponding lvec1 codes in fac
    for(i=1;i<=*nt1;i++) {
        tab[lvec2[i-1]][cvec1[i-1]]+=1;
        strata[lvec2[i-1]]=lvec1[i-1];
    }
    
    //Aggregates the rows of tab in redtab according to fac
    for(i=1;i<=*nl2;i++)
        for(j=1;j<=*nc1;j++)
            redtab[strata[i]][j]+=tab[i][j];
    
    //Computes initial by-column variances between the rows of redtab
    varinter2(redtab,*nl1,*nc1,*nt1,varobs,cw);

	//Stores observed species variances and diversity indices in varobs and divobs
	for (j=1;j<=*nc1;j++) {
		if(cw[j]>0) {
			divobs[1]+=varobs[j]/cw[j];
			divobs[2]+=varobs[j]*log(1/cw[j])/(1-cw[j]);
			divobs[3]+=varobs[j];
		}
	}

    //Creates cross-classifying redtab from tab randomized by rows
    //Computesspecies variances and diversity indices from redtab
   //Returns the number of times they are exceeding observed values in the R variable res1
    for (k=1; k<=*np1; k++) {
		taballoc(&redtab,*nl1,*nc1);
		vecintalloc(&numero,*nl2);
		vecalloc(&varsim,*nc1);
		vecalloc(&cw,*nc1);
		vecalloc(&dsim,3);
		getpermutation(numero,k);
		for(i=1;i<=*nl2;i++)
			for(j=1;j<=*nc1;j++)
				redtab[strata[i]][j]+=tab[numero[i]][j];
        varinter2(redtab,*nl1,*nc1,*nt1,varsim,cw);
        for (j=1;j<=*nc1;j++) {
			if(varsim[j]>=varobs[j]) {
				res[j-1]+=1;
			}
			if(cw[j]>0) {
				dsim[1]+=varsim[j]/cw[j];
				dsim[2]+=varsim[j]*log(1/cw[j])/(1-cw[j]);
				dsim[3]+=varsim[j];
			}
		}
		if(dsim[1]>=divobs[1])
			res[*nc1]+=1;
		if(dsim[2]>=divobs[2]) 
			res[*nc1+1]+=1;
		if(dsim[3]>=divobs[3])
			res[*nc1+2]+=1;
  }
  
  freetab(tab);
  freetab(redtab);
  freeintvec(numero);
  freevec(varsim);
  freeintvec(strata);
  freevec(cw);
  freevec(varobs);
  freevec(divobs);
  freevec(dsim);
}

/************************************************************************/
/*Returns in vector res:												*/
/****first nc1 values=observed by-column variances between rows of tab 	*/
/*which crosses	lvec1 with cvec1. tab has size nl1*nc1 and sums to nt1.	*/
/****next np1*nc1 values=np1 times the same after randomization of cvec1*/
/************************************************************************/
void testinter1(int *cvec1,int *nc1,int *lvec1,int *nl1,int *nt1,int *np1,double *res) {	
    double **tab,*var;
    int i,j,k;
    int *numero;
    taballoc(&tab,*nl1,*nc1);
    vecalloc(&var,*nc1);
    vecintalloc(&numero,*nt1);
    
    //Creates the cross-classifying tab from lvec1 and cvec1
   // for(i=0;i<*nt1;i++)
    //    tab[lvec1[i]][cvec1[i]]+=1;
	for(i=1;i<=*nt1;i++)
		tab[lvec1[i-1]][cvec1[i-1]]+=1;
        
    //Returns in var the initial by-column variances between the rows of tab
    varinter(tab,*nl1,*nc1,*nt1,var);
    //Writes the C variable var within the R variable res
    for (j=1;j<=*nc1;j++)
            res[j-1]=var[j];
     
    //Creates cross-classifying tab from lvec1 and randomized cvec1
    //Computes by-column variances between the rows of tab
    //Writes the C variable var within the R variable res                   
    for (k=1; k<*np1; k++) {
        getpermutation(numero,k);
        taballoc(&tab,*nl1,*nc1);
        //for(i=0;i<*nt1;i++)
           // tab[lvec1[i]][cvec1[numero[i+1]]]+=1;
		for(i=1;i<=*nt1;i++)
           tab[lvec1[i-1]][cvec1[numero[i]-1]]+=1;
        vecalloc(&var,*nc1);
        varinter(tab,*nl1,*nc1,*nt1,var);
        for (j=1;j<=*nc1;j++)
                res[k*(*nc1)+(j-1)]=var[j];
      } 
  
  
  freetab(tab);
  freeintvec(numero);
  freevec(var);
}

/******************************************/
/*idem testinter1 but returns only pvalues*/
/******************************************/
void testinter2(int *cvec1,int *nc1,int *lvec1,int *nl1,int *nt1,int *np1,double *res) {
    double **tab,*varsim,*cw,*dsim;
    int i,j,k;
    int *numero;
	double *varobs,*divobs;
    taballoc(&tab,*nl1,*nc1);
	vecalloc(&cw,*nc1);
	vecalloc(&varobs,*nc1);
	vecalloc(&divobs,3);
    
    //Creates the cross-classifying tab from lvec1 and cvec1
    for(i=1;i<=*nt1;i++)
        tab[lvec1[i-1]][cvec1[i-1]]+=1;
	
    //Returns by-column variances between the rows of tab in var 
	//and species weights in cw
	 varinter2(tab,*nl1,*nc1,*nt1,varobs,cw);


    //Stores observed species variances and diversity indices in varobs and divobs
    for (j=1;j<=*nc1;j++)
		if(cw[j]>0) {
			divobs[1]+=varobs[j]/cw[j];
			divobs[2]+=varobs[j]*log(1/cw[j])/(1-cw[j]);
			divobs[3]+=varobs[j];
		}
   
    //Creates cross-classifying tab from lvec1 and randomized cvec1
    //Computes species variances and diversity indices from tab
	//Returns the number of times they are exceeding observed values in the R variable res1
   for (k=1; k<=*np1; k++) {
   		taballoc(&tab,*nl1,*nc1);
		vecintalloc(&numero,*nt1);
		vecalloc(&varsim,*nc1);
		vecalloc(&cw,*nc1);
		vecalloc(&dsim,3);
		getpermutation(numero,k);
		for(i=1;i<=*nt1;i++)
			tab[lvec1[i-1]][cvec1[numero[i]-1]]+=1;
		varinter2(tab,*nl1,*nc1,*nt1,varsim,cw);
		for (j=1;j<=*nc1;j++) {
			if(varsim[j]>=varobs[j]) {
				res[j-1]+=1;
			}
			if(cw[j]>0) {
				dsim[1]+=varsim[j]/cw[j];
				dsim[2]+=varsim[j]*log(1/cw[j])/(1-cw[j]);
				dsim[3]+=varsim[j];
			}
		}
		if(dsim[1]>=divobs[1])
			res[(*nc1)]+=1;
		if(dsim[2]>=divobs[2])
			res[(*nc1)+1]+=1;
		if(dsim[3]>=divobs[3])
			res[(*nc1)+2]+=1;
	}
	
	freetab(tab);
	freeintvec(numero);
	freevec(varsim);
	freevec(cw);
	freevec(dsim);
	freevec(varobs);
	freevec(divobs);
}

/************************************************************************/
/*Returns in vector res:												*/
/****first nc1 values=mean observed by-column variances between the rows of redtab */
/*which is an extraction for each level of lvec2, of tab crosses lvec1 with cvec1 */
/*tab has size nl1*nc1 and sums to nt1. redtab has size nl2*nc1 and sums to str_ni*/
/************************************************************************/
/*void testwithin(int *cvec1,int *nc1,int *lvec1,int *nl1,int *lvec2,int *nl2,int *nt1,int *np1, double *res)
{	
    double **tab,*var,**redtab,*vark;
    int i,j,k,l;
    int *numero,*strata,*str_nlev,*str_ni;
    taballoc(&tab,*nl2,*nc1);
    vecintalloc(&str_ni,*nl1);
    vecintalloc(&str_nlev,*nl1);
    vecintalloc(&strata,*nl2);
    vecintalloc(&numero,*nt1);
    vecalloc(&var,*nc1);

    //Creates the cross-classifying tab from lvec2 and cvec1
    //Stores the corresponding lvec1 codes in strata
    //Stores the number of observations per strata in str_ni
    for(i=0;i<*nt1;i++) {
        tab[lvec2[i]][cvec1[i]]+=1;
        strata[lvec2[i]]=lvec1[i];
        str_ni[lvec1[i]]+=1;
    }
    
    //Stores the number of lvec2 per lvec1 in str_nlev
    for(i=1;i<=*nl2;i++)
   	str_nlev[strata[i]]+=1;
     
    //Returns in var the mean initial by-column within strata variances
    //between the rows of tab
//varcond(tab,*nl1,*nc1,*nt1,*nl2,strata,str_nlev,str_ni,var);

    for(k=1;k<=*nl1;k++) {
    
 	taballoc(&redtab,str_nlev[k],*nc1);
        l=1;
        //Writes in redtab an extraction of tab for ecah strata
        for(i=1;i<=*nl2;i++)
            if(strata[i]==k) {
                for(j=1;j<=*nc1;j++)
                    redtab[l][j]=tab[i][j];
                l+=1;
            }
        vecalloc(&vark,*nc1);
        //Return in var by-column variances between the rows of redtab 
        varinter(redtab,str_nlev[k],*nc1,str_ni[k],vark);
        
        //Sums the weighted var of each strata
        for(j=1;j<=*nc1;j++)             
            var[j]+=str_ni[k]*vark[j]/(double)(*nt1);
    }
        
      //Writes the C variable var within the R variable res
    
    for (j=1;j<=*nc1;j++)
            res[j-1]=var[j];
                
    freeintvec(numero);
    freevec(var);
    freevec(vark);
    freeintvec(str_ni);
    freeintvec(strata);
    freeintvec(str_nlev);
    freetab(tab);
    freetab(redtab);
}*/

/************************************************************************/
/*Returns in vector res:												*/
/****first nc1 values=mean observed by-column variances between the rows of redtab */
/*which crosses lvec2 with cvec1 whithin each level of lvec1.*/
/*redtab has size nl2*nc1 and sums to str_ni*/
/****next np1*nc1 values=np1 times the same after randomization of cvec1 within the levels of lvec2*/
/************************************************************************/
void testwithin1(int *cvec1,int *nc1,int *lvec1,int *nl1,int *lvec2,int *nl2,int *nt1,int *np1, double *res)
{	
   double **tab,*var,**redtab,*vark;
    int i,j,k,l,n,nl;
    int *numero,*strata,*str_nlev,*str_ni;
    int *redlvec2,*redlvec2bis,*redcvec1;
    taballoc(&tab,*nl2,*nc1);
    vecintalloc(&str_ni,*nl1);
    vecintalloc(&str_nlev,*nl1);
    vecintalloc(&strata,*nl2);
    vecalloc(&var,*nc1);
    

     for(i=0;i<*nt1;i++) {
       strata[lvec2[i]]=lvec1[i];
       str_ni[lvec1[i]]+=1;
    }
    for(i=1;i<=*nl2;i++)
        str_nlev[strata[i]]+=1;
       
    for(k=1;k<=*nl1;k++) {
        nl=str_nlev[k];
        n=str_ni[k];
        vecintalloc(&redlvec2,n);
        vecintalloc(&redlvec2bis,n);
        vecintalloc(&redcvec1,n);
        l=1;
        for(i=0;i<*nt1;i++) {
            if(lvec1[i]==k) {
               redlvec2[l]=lvec2[i];
               redcvec1[l]=cvec1[i];
               l+=1;
            }
        }
        changeintlevels(redlvec2,redlvec2bis);
        taballoc(&redtab,nl,*nc1);
        for(i=1;i<=n;i++)
            redtab[redlvec2bis[i]][redcvec1[i]]+=1;
        vecalloc(&vark,*nc1);
        varinter(redtab,nl,*nc1,n,vark);
        for(j=1;j<=*nc1;j++)
            res[j-1]+=n*vark[j]/(double)(*nt1);

        for(l=1;l<=*np1;l++) {
            vecintalloc(&numero,n);
            taballoc(&redtab,nl,*nc1);
           //getpermutation(numero,k);
		   getpermutation(numero,l);
            for(i=1;i<=n;i++) {
                //numero[i]=i;
                redtab[redlvec2bis[i]][redcvec1[numero[i]]]+=1;
            }
            vecalloc(&vark,*nc1);
            varinter(redtab,nl,*nc1,n,vark);   
            for (j=1;j<=*nc1;j++)
                res[l*(*nc1)+(j-1)]+=n*vark[j]/(double)(*nt1);
    
		}
    }
            
  freeintvec(numero);
 freevec(var);
 freevec(vark);
  freeintvec(str_ni);
  freeintvec(strata);
  freeintvec(str_nlev);
  freetab(tab);
 freetab(redtab);
 freeintvec(redlvec2);
 freeintvec(redlvec2bis);
    freeintvec(redcvec1);

}

/******************************************/
/*idem testwithin1 but returns only pvalues*/
/******************************************/
void testwithin2(int *cvec1,int *nc1,int *lvec1,int *nl1,int *lvec2,int *nl2,int *nt1,int *np1, double *res) {	
   double *varobs,**redtab,*vark,*cwk,*cwobs;
   double *divobs,**varsim,**disim;
    int i,j,k,l,n,nl;
    int *numero,*strata,*str_nlev,*str_ni;
    int *redlvec2,*redlvec2bis,*redcvec1;
    vecintalloc(&str_ni,*nl1);
    vecintalloc(&str_nlev,*nl1);
    vecintalloc(&strata,*nl2);
	vecalloc(&varobs,*nc1);
	vecalloc(&divobs,3);
	vecalloc(&cwobs,*nc1);
	taballoc(&varsim,*np1,*nc1);
	taballoc(&disim,*np1,3);
		
     for(i=1;i<=*nt1;i++) {
       strata[lvec2[i-1]]=lvec1[i-1];
       str_ni[lvec1[i-1]]+=1;
    }
    for(i=1;i<=*nl2;i++)
        str_nlev[strata[i]]+=1;
	freeintvec(strata);
       
    for(k=1;k<=*nl1;k++) {
        nl=str_nlev[k];
        n=str_ni[k];
        vecintalloc(&redlvec2,n);
        vecintalloc(&redlvec2bis,n);
        vecintalloc(&redcvec1,n);
        l=1;
        for(i=1;i<=*nt1;i++) {
            if(lvec1[i-1]==k) {
               redlvec2[l]=lvec2[i-1];
               redcvec1[l]=cvec1[i-1];
               l+=1;
            }
        }
        changeintlevels(redlvec2,redlvec2bis);
        taballoc(&redtab,nl,*nc1);
        for(i=1;i<=n;i++)
            redtab[redlvec2bis[i]][redcvec1[i]]+=1;
        vecalloc(&vark,*nc1);
		vecalloc(&cwk,*nc1);
		varinter2(redtab,nl,*nc1,n,vark,cwk);
        for(j=1;j<=*nc1;j++) {
            varobs[j]+=n*vark[j]/(double)(*nt1);
			cwobs[j]+=cwk[j]*n;
		}
			
        for(l=1;l<=*np1;l++) {
			vecintalloc(&numero,n);
			for(j=1;j<=*nc1;j++) {
				vark[j]=0;
				cwk[j]=0;
				for(i=1;i<=nl;i++)
					redtab[i][j]=0;
			}
			getpermutation(numero,l);
            for(i=1;i<=n;i++)
                redtab[redlvec2bis[i]][redcvec1[numero[i]]]+=1;
			varinter2(redtab,nl,*nc1,n,vark,cwk);   
           for (j=1;j<=*nc1;j++)
                varsim[l][j]+=n*vark[j]/(double)(*nt1);
		}
   	}
	freeintvec(str_ni);
	freeintvec(str_nlev);
	freeintvec(redlvec2);
	freeintvec(redlvec2bis);
    freeintvec(redcvec1);
	freetab(redtab);
	freevec(vark);
	freevec(cwk);
	freeintvec(numero);
	
	for(j=1;j<=*nc1;j++)
		if(cwobs[j]>0) {
			divobs[1]+=varobs[j]/cwobs[j];
			divobs[2]+=varobs[j]*log(1/cwobs[j])/(1-cwobs[j]);
			divobs[3]+=varobs[j];
		}
	
	for(l=1;l<=*np1;l++) 
		for(j=1;j<=*nc1;j++) {
			if(varsim[l][j]>=varobs[j])
				res[j-1]+=1;
			if(cwobs[j]>0) {
				disim[l][1]+=varsim[l][j]/cwobs[j];
				disim[l][2]+=varsim[l][j]*log(1/cwobs[j])/(1-cwobs[j]);
				disim[l][3]+=varsim[l][j];
			}
		}
	
	for(l=1;l<=*np1;l++) {
		if(disim[l][1]>=divobs[1])
			res[(*nc1)]+=1;
		if(disim[l][2]>=divobs[2])
			res[(*nc1)+1]+=1;
		if(disim[l][3]>=divobs[3])
			res[(*nc1)+2]+=1;
	}

	freevec(varobs);
	freevec(divobs);
	freevec(cwobs);
	freetab(varsim);
	freetab(disim);
	
}

/************************************************************************/
/*idem testwithin2, mais autre version					*/
/************************************************************************/
/*void testwithin3(int *cvec1,int *nc1,int *lvec1,int *nl1,int *lvec2,int *nl2,int *nt1,int *np1, double *res1) {	
   double *varobs,**redtab,*vark,*cwk,*cw;
   double *divobs,*varsim,*disim;
    int i,j,k,l,n,nl,q;
    int *numero,*strata,*str_nlev,*str_ni;
    int *redlvec2,*redlvec2bis,*redcvec1;
	vecintalloc(&strata,*nl2);
	vecintalloc(&str_ni,*nl1);
    vecintalloc(&str_nlev,*nl1);
	vecalloc(&varobs,*nc1);
	vecalloc(&cw,*nc1);
	vecalloc(&divobs,3);
		
     for(i=1;i<=*nt1;i++) {
       strata[lvec2[i-1]]=lvec1[i-1];
       str_ni[lvec1[i-1]]+=1;
	}
    for(i=1;i<=*nl2;i++)
        str_nlev[strata[i]]+=1;
	freeintvec(strata);

	
	for(k=1;k<=*nl1;k++) {
        nl=str_nlev[k];
        n=str_ni[k];
        vecintalloc(&redlvec2,n);
        vecintalloc(&redlvec2bis,n);
        vecintalloc(&redcvec1,n);
        q=1;
        for(i=1;i<=*nt1;i++)
            if(lvec1[i-1]==k) {
               redlvec2[q]=lvec2[i-1];
               redcvec1[q]=cvec1[i-1];
               q+=1;
            }
        changeintlevels(redlvec2,redlvec2bis);
        taballoc(&redtab,nl,*nc1);
        for(i=1;i<=n;i++)
            redtab[redlvec2bis[i]][redcvec1[i]]+=1;
        vecalloc(&vark,*nc1);
		vecalloc(&cwk,*nc1);
		varinter2(redtab,nl,*nc1,n,vark,cwk);
        for(j=1;j<=*nc1;j++) {
            varobs[j]+=n*vark[j]/(double)(*nt1);
			cw[j]+=cwk[j]*n;
		}
	}
	for(j=1;j<=*nc1;j++)
		if(cw[j]>0) {
			divobs[1]+=varobs[j]/cw[j];
			divobs[2]+=varobs[j]*log(1/cw[j])/(1-cw[j]);
			divobs[3]+=varobs[j];
		}
		
		
for(l=1;l<=*np1;l++) {		
	vecalloc(&varsim,*nc1);
	vecalloc(&cw,*nc1);
	vecalloc(&disim,3);

		
		for(k=1;k<=*nl1;k++) {
        nl=str_nlev[k];
        n=str_ni[k];
        vecintalloc(&redlvec2,n);
        vecintalloc(&redlvec2bis,n);
        vecintalloc(&redcvec1,n);
        q=1;
        for(i=1;i<=*nt1;i++)
            if(lvec1[i-1]==k) {
               redlvec2[q]=lvec2[i-1];
               redcvec1[q]=cvec1[i-1];
               q+=1;
            }
        changeintlevels(redlvec2,redlvec2bis);
        taballoc(&redtab,nl,*nc1);
        for(i=1;i<=n;i++)
            redtab[redlvec2bis[i]][redcvec1[i]]+=1;
        vecalloc(&vark,*nc1);
		vecalloc(&cwk,*nc1);
		varinter2(redtab,nl,*nc1,n,vark,cwk);
        for(j=1;j<=*nc1;j++) {
            varsim[j]+=n*vark[j]/(double)(*nt1);
			cw[j]+=cwk[j]*n;
		}
	}
	for(j=1;j<=*nc1;j++)
		if(cw[j]>0) {
			disim[1]+=varsim[j]/cw[j];
			disim[2]+=varsim[j]*log(1/cw[j])/(1-cw[j]);
			disim[3]+=varsim[j];
		}
}*/

		
/*for(l=1;l<=*np1;l++) {
		vecalloc(&varsim,*nc1);
		vecalloc(&disim,3);
		vecalloc(&cw,*nc1);
		
		for(k=1;k<=*nl1;k++) {
			nl=str_nlev[k];
			n=str_ni[k];
			vecintalloc(&redlvec2,n);
			vecintalloc(&redlvec2bis,n);
			vecintalloc(&redcvec1,n);
			q=1;
			for(i=1;i<=*nt1;i++)
				if(lvec1[i-1]==k) {
					redlvec2[q]=lvec2[i-1];
					redcvec1[q]=cvec1[i-1];
					q+=1;
				}
			changeintlevels(redlvec2,redlvec2bis);
			vecintalloc(&numero,n);
			getpermutation(numero,l);
            taballoc(&redtab,nl,*nc1);
			for(i=1;i<=n;i++)
			    redtab[redlvec2bis[i]][redcvec1[numero[i]]]+=1;
			vecalloc(&vark,*nc1);
			vecalloc(&cwk,*nc1);
            varinter2(redtab,nl,*nc1,n,vark,cwk);   
           for (j=1;j<=*nc1;j++) {
                varsim[j]+=n*vark[j]/(double)(*nt1);
				cw[j]+=cwk[j]*n;
			}
		}
		for(j=1;j<=*nc1;j++) {
			if(varsim[j]>=varobs[j])
				res1[j-1]+=1;
			if(cw[j]>0) {
				disim[1]+=varsim[j]/cw[j];
				disim[2]+=varsim[j]*log(1/cw[j])/(1-cw[j]);
				disim[3]+=varsim[j];
			}
		}
		if(disim[1]>=divobs[1])
			res1[(*nc1)]+=1;
		if(disim[2]>=divobs[2])
			res1[(*nc1)+1]+=1;
		if(disim[3]>=divobs[3])
			res1[(*nc1)+2]+=1;
				
	}*/
	
/*	freeintvec(str_ni);
	freeintvec(str_nlev);
	freeintvec(redlvec2);
	freeintvec(redlvec2bis);
    freeintvec(redcvec1);
	freetab(redtab);
	freevec(vark);
	freevec(cwk);
	freevec(varobs);
	freevec(cw);
	freevec(divobs);
	freevec(varsim);
	freevec(disim);
	//freeintvec(numero);
}*/

/************************************************************************/
/*Returns in vector res:												*/
/****first nc1 values=mean observed by-column variances between the rows of redtab2 */
/*which crosses lvec2 with cvec1 whithin each level of lvec1.*/
/*redtab2 has size nl2*nc1 and sums to str_ni*/
/****next np1*nc1 values=np1 times the same after randomization of levec3 across levec2 within the levels of lvec1*/
/************************************************************************/
void testacrosswithin1(int *cvec1,int *nc1,int *lvec1,int *nl1,int *lvec2,int *nl2,int *lvec3,int *nl3,int *nt1,int *np1, double *res) {	
	double **tab3,**redtab2,**redtab3,*vark;
	int *strata1_t2,*str1_ni,*str1_nlev2;
	int *strata1_t3,*strata2_t3,*str1_nlev3,*redstr2,*redstr2bis;
	int i,j,k,l;
	int n2,n3,n;
    int *numero;
	
	taballoc(&tab3,*nl3,*nc1);
	vecintalloc(&strata1_t3,*nl3);
	vecintalloc(&strata2_t3,*nl3);
	vecintalloc(&strata1_t2,*nl2);
	vecintalloc(&str1_ni,*nl1);
	vecintalloc(&str1_nlev3,*nl1);
	vecintalloc(&str1_nlev2,*nl1);
	    
	 //Creates the cross-classifying tab3 from lvec3 and cvec1
	 //Store levec1 and lvec2 codes per lvec3 and lvec2 levels
    for(i=0;i<*nt1;i++) {
		tab3[lvec3[i]][cvec1[i]]+=1;
		strata1_t3[lvec3[i]]=lvec1[i]; // code lev1 per lev3
		strata2_t3[lvec3[i]]=lvec2[i]; // code lev2 per lev3
		strata1_t2[lvec2[i]]=lvec1[i]; // code lev1 per lev2
		str1_ni[lvec1[i]]+=1;	//nb indiv per lev1
	}
	
	for(i=1;i<=*nl3;i++)
		str1_nlev3[strata1_t3[i]]+=1; //nb lev3 per lev1
	for(i=1;i<=*nl2;i++)
		str1_nlev2[strata1_t2[i]]+=1; //nb lev2 per lev1
	
	for(k=1;k<=*nl1;k++) {
		n2=str1_nlev2[k];
		n3=str1_nlev3[k];
		n=str1_ni[k];
		//extraction of tab3 and strata2_t3 for each lev1
		taballoc(&redtab3,n3,*nc1);
		vecintalloc(&redstr2,n3);
		vecintalloc(&redstr2bis,n3);
		l=1;
		for(i=1;i<=*nl3;i++) {
			if(strata1_t3[i]==k) {
				for(j=1;j<=*nc1;j++)
					redtab3[l][j]=tab3[i][j];
				redstr2[l]=strata2_t3[i];
				l+=1;
			}
		}
		changeintlevels(redstr2,redstr2bis);
		//Aggregates the rows of redtab3 in redtab2 according to redstr2bis
		taballoc(&redtab2,n2,*nc1);
		for(i=1;i<=n3;i++)
			for(j=1;j<=*nc1;j++)
				redtab2[redstr2bis[i]][j]+=redtab3[i][j];
		vecalloc(&vark,*nc1);
		varinter(redtab2,n2,*nc1,n,vark);
        for(j=1;j<=*nc1;j++)
			res[j-1]+=n*vark[j]/(double)(*nt1);
		//randomizations of lev3 across lev2 within lev1	
		for(l=1;l<=*np1;l++) {
			vecintalloc(&numero,n3);
			taballoc(&redtab2,n2,*nc1);
			//getpermutation(numero,k);
			getpermutation(numero,l);
			for(i=1;i<=n3;i++)
				for(j=1;j<=*nc1;j++)
					redtab2[redstr2bis[i]][j]+=redtab3[numero[i]][j];
			vecalloc(&vark,*nc1);
            varinter(redtab2,n2,*nc1,n,vark);   
            for (j=1;j<=*nc1;j++)
                res[l*(*nc1)+(j-1)]+=n*vark[j]/(double)(*nt1);
			}
	}
	freetab(tab3);
	freeintvec(strata1_t3);
	freeintvec(strata2_t3);
	freeintvec(strata1_t2);
	freeintvec(str1_ni);
	freeintvec(str1_nlev2);
	freeintvec(str1_nlev3);
	freetab(redtab3);
	freeintvec(redstr2);
	freeintvec(redstr2bis);
	freetab(redtab2);
	freevec(vark);
	freeintvec(numero);
}
/****************************************************/
/*idem testacrosswithin1 but returns only pvalues pvalues*/
/***************************************************/ 
void testacrosswithin2(int *cvec1,int *nc1,int *lvec1,int *nl1,int *lvec2,int *nl2,int *lvec3,int *nl3,int *nt1,int *np1, double *res) {	
	double **tab3,**redtab2,**redtab3,*vark;
	double *cwk,*cwobs,*varobs,*divobs,**varsim,**disim;
	int *strata1_t2,*str1_ni,*str1_nlev2;
	int *strata1_t3,*strata2_t3,*str1_nlev3,*redstr2,*redstr2bis;
	int i,j,k,l;
	int n2,n3,n;
    int *numero;
	
	taballoc(&tab3,*nl3,*nc1);
	vecintalloc(&strata1_t3,*nl3);
	vecintalloc(&strata2_t3,*nl3);
	vecintalloc(&strata1_t2,*nl2);
	vecintalloc(&str1_ni,*nl1);
	vecintalloc(&str1_nlev3,*nl1);
	vecintalloc(&str1_nlev2,*nl1);
	
	vecalloc(&varobs,*nc1);
	vecalloc(&divobs,3);
	vecalloc(&cwobs,*nc1);
	taballoc(&varsim,*np1,*nc1);
	taballoc(&disim,*np1,3);
	
	    
	 //Creates the cross-classifying tab3 from lvec3 and cvec1
	 //Store levec1 and lvec2 codes per lvec3 and lvec2 levels
    for(i=0;i<*nt1;i++) {
		tab3[lvec3[i]][cvec1[i]]+=1;
		strata1_t3[lvec3[i]]=lvec1[i]; // code lev1 per lev3
		strata2_t3[lvec3[i]]=lvec2[i]; // code lev2 per lev3
		strata1_t2[lvec2[i]]=lvec1[i]; // code lev1 per lev2
		str1_ni[lvec1[i]]+=1;	//nb indiv per lev1
	}
	
	for(i=1;i<=*nl3;i++)
		str1_nlev3[strata1_t3[i]]+=1; //nb lev3 per lev1
	for(i=1;i<=*nl2;i++)
		str1_nlev2[strata1_t2[i]]+=1; //nb lev2 per lev1
	
	for(k=1;k<=*nl1;k++) {
		n2=str1_nlev2[k];
		n3=str1_nlev3[k];
		n=str1_ni[k];
		//extraction of tab3 and strata2_t3 for each lev1
		taballoc(&redtab3,n3,*nc1);
		vecintalloc(&redstr2,n3);
		vecintalloc(&redstr2bis,n3);
		l=1;
		for(i=1;i<=*nl3;i++) {
			if(strata1_t3[i]==k) {
				for(j=1;j<=*nc1;j++)
					redtab3[l][j]=tab3[i][j];
				redstr2[l]=strata2_t3[i];
				l+=1;
			}
		}
		changeintlevels(redstr2,redstr2bis);
		//Aggregates the rows of redtab3 in redtab2 according to redstr2bis
		taballoc(&redtab2,n2,*nc1);
		for(i=1;i<=n3;i++)
			for(j=1;j<=*nc1;j++)
				redtab2[redstr2bis[i]][j]+=redtab3[i][j];
		vecalloc(&vark,*nc1);
		vecalloc(&cwk,*nc1);
		varinter2(redtab2,n2,*nc1,n,vark,cwk);
		for(j=1;j<=*nc1;j++) {
            varobs[j]+=n*vark[j]/(double)(*nt1);
			cwobs[j]+=cwk[j]*n;
		}
		
		//randomizations of lev3 across lev2 within lev1	
		for(l=1;l<=*np1;l++) {
			vecintalloc(&numero,n3);
			//taballoc(&redtab2,n2,*nc1);
			for(j=1;j<=*nc1;j++) {
				vark[j]=0;
				cwk[j]=0;
				for(i=1;i<=n2;i++)
					redtab2[i][j]=0;
			}
			//getpermutation(numero,k);
			getpermutation(numero,l);
			for(i=1;i<=n3;i++)
				for(j=1;j<=*nc1;j++)
					redtab2[redstr2bis[i]][j]+=redtab3[numero[i]][j];
			//vecalloc(&vark,*nc1);
            varinter2(redtab2,n2,*nc1,n,vark,cwk);   
			for (j=1;j<=*nc1;j++)
                varsim[l][j]+=n*vark[j]/(double)(*nt1);
	
		}
	}
	freetab(tab3);
	freeintvec(str1_ni);
	freeintvec(str1_nlev2);
	freeintvec(str1_nlev3);
	freeintvec(strata1_t3);
	freeintvec(strata1_t2);
	freeintvec(strata2_t3);
	freetab(redtab3);
	freeintvec(redstr2);
	freeintvec(redstr2bis);
	freetab(redtab2);
	freevec(vark);
	freevec(cwk);
	freeintvec(numero);
	
	for(j=1;j<=*nc1;j++)
		if(cwobs[j]>0) {
			divobs[1]+=varobs[j]/cwobs[j];
			divobs[2]+=varobs[j]*log(1/cwobs[j])/(1-cwobs[j]);
			divobs[3]+=varobs[j];
		}
	
	for(l=1;l<=*np1;l++) {
		for(j=1;j<=*nc1;j++) {
			if(varsim[l][j]>=varobs[j])
				res[j-1]+=1;
			if(cwobs[j]>0) {
				disim[l][1]+=varsim[l][j]/cwobs[j];
				disim[l][2]+=varsim[l][j]*log(1/cwobs[j])/(1-cwobs[j]);
				disim[l][3]+=varsim[l][j];
			}
		}
	}
	for(l=1;l<=*np1;l++) {
		if(disim[l][1]>=divobs[1])
			res[(*nc1)]+=1;
		if(disim[l][2]>=divobs[2])
			res[(*nc1)+1]+=1;
		if(disim[l][3]>=divobs[3])
			res[(*nc1)+2]+=1;
	}

	freevec(varobs);
	freevec(divobs);
	freevec(cwobs);
	freetab(varsim);
	freetab(disim);
}

/************************************************************************/
/*Returns in vector var, by-column variances between the rows of tab  	*/
/* with size (nl1,nc1) and which sums to (nt1).				*/  
/************************************************************************/
void Vinter(double *tab1,int *nl1,int *nc1,int *nt1,double *res)
{
    double **tab,*var;
    int i,j,k;
    
    taballoc(&tab,*nl1,*nc1);
    vecalloc(&var,*nc1);
  
    //Writes R variables within C variables
    k=0;
    for (i=1;i<=*nl1; i++)
        for (j=1; j<=*nc1;j++) {
            tab[i][j] = tab1[k];
            k=k+1;
        }

    //Computes by-column variances between the rows of tab
    varinter(tab,*nl1,*nc1,*nt1,var);

    //Writes C variables within an R variables  
    for (j=1;j<=*nc1;j++)
            res[j-1]=var[j];

    freetab(tab);
    freevec(var);
}




