#include <math.h>
#include <time.h>
#include <string.h>
#include <stdlib.h>
#include "adesub.h"
#include "diversitysub.h"

/************************************************************************/
/*----------Internal sub-routines------Cannot be called from R----------*/
/************************************************************************/
/************************************************************************/
/*Returns in vector var, by-column variances between the rows of tab  	*/
/* with size (nl,nc) and which sums to (nt).				*/  
/************************************************************************/
void varinter(double **tab,int nl,int nc,int nt,double *var)
{	
    double *pl,*pc;
    int i,j;
    vecalloc(&pc,nc);
    vecalloc(&pl,nl);
    
    //Computes matrix of relative frequencies and vectors of row and col weights
    for (i=1;i<=nl; i++)
        for (j=1; j<=nc;j++) {
            tab[i][j]=tab[i][j]/((double)(nt));
            pc[j]+=tab[i][j];
            pl[i]+=tab[i][j];
        }
    
    //Computes by-column variances between the rows of tab 
    for (j=1;j<=nc;j++)
        for (i=1;i<=nl; i++)
            var[j]+=pl[i]*(tab[i][j]/pl[i]-pc[j])*(tab[i][j]/pl[i]-pc[j]);
    freevec(pc);
    freevec(pl);
}

/********************************************************/
/*idem varinter but returns the species weights in vec c*/
/*******************************************************/
void varinter2(double **t,int nl,int nc,int nt,double *v,double *c) {	
	double *pl;
    int i,j;
    vecalloc(&pl,nl);
    
    //Computes matrix of relative frequencies and vectors of row and col weights
    for (i=1;i<=nl; i++)
        for (j=1; j<=nc;j++) {
			t[i][j]=t[i][j]/((double)(nt));
            c[j]+=t[i][j];
            pl[i]+=t[i][j];
        }
    
    //Computes by-column variances between the rows of tab 
    for (j=1;j<=nc;j++) {
        for (i=1;i<=nl; i++)
            v[j]+=pl[i]*(t[i][j]/pl[i]-c[j])*(t[i][j]/pl[i]-c[j]);
	}
    freevec(pl);
}

/************************************************************************/
/*Returns in vector var, the mean by-column within-strata variances 	*/
/*between the rows of tab with size (nl2,nc1) and which sums to (nt1).	*/
/*Vector strata contains indices for the rows of tab. The number of 	*/
/*observations and the number of rows of tab per strata are respectively*/
/*in vectors str_ni and str_nlev of length (nl1).			*/  
/************************************************************************/
/*void varcond(double **tab,int nl1,int nc1,int nt1,int nl2,int *strata,int *str_nlev,int *str_ni, double *var)
{	
    int i,j,k,l;
    double **redtab,*vark;
    
    for(k=1;k<=nl1;k++) {
 	taballoc(&redtab,str_nlev[k],nc1);
        l=1;
        //Writes in redtab an extraction of tab for ecah strata
        for(i=1;i<=nl2;i++)
            if(strata[i]==k) {
                for(j=1;j<=nc1;j++)
                    redtab[l][j]=tab[i][j];
                l+=1;
            }
        vecalloc(&vark,nc1);
        //Return in var by-column variances between the rows of redtab 
        varinter(redtab,str_nlev[k],nc1,str_ni[k],vark);
        //Sums the weighted var of each strata
        for (j=1;j<=nc1;j++)             
            var[j]+=str_ni[k]*vark[j]/(double)(nt1);
    }
    freevec(vark);
    freetab(redtab);
}*/
/**********/
void changeintlevels(int *vecp, int *res)
/*--------------------------------------------------
* on va numroter les levels de vecp de 1  n
--------------------------------------------------*/
{

	int i, j, k, l, lenvecp, lenundup, *unduplicvecp;
	
	vecintalloc (&unduplicvecp, vecp[0]);
	
	lenvecp = vecp[0];
	unduplicint(vecp, unduplicvecp);
	lenundup = unduplicvecp[0];
	
	for(i = 1; i <= lenvecp; i++){
			for(j = 1; j <= lenundup; j++){
				k = vecp[i];
				l = unduplicvecp[j];
				if(k == l){
					res[i] = j;

				}
			}
	}
	
	freeintvec(unduplicvecp);
	
}
/***************************************************************/
void unduplicint(int *vecp, int *res)
/*--------------------------------------------------
*
--------------------------------------------------*/
{

	int i, j, k, lenvecp, compteur;
	lenvecp = vecp[0];
	
	k = 1;
	res[1] = vecp[1];
	for(i = 2; i <= lenvecp; i++){
		compteur = 0;
		for(j = 1; j <= k; j++){
			if(vecp[i] != res[j]){
				compteur = compteur + 1;
			}
		}
		if(compteur == k){
			res[k + 1] = vecp[i];
			k = k + 1;
		}
	}
	res[0] = k;

}

/*************************/
/*from pkg "stats"
 /**********/

/*static double R_euclidean(double *x, int nr, int nc, int i1, int i2)
{
    double dev, dist;
    int count, j;
	
    count= 0;
    dist = 0;
    for(j = 0 ; j < nc ; j++) {
		//if(both_non_NA(x[i1], x[i2])) {
			dev = (x[i1] - x[i2]);
			//if(!ISNAN(dev)) {
				dist += dev * dev;
				count++;
		//	}
		//}
		i1 += nr;
		i2 += nr;
    }
    //if(count == 0) return NA_REAL;
    if(count != nc) dist /= ((double)count/nc);
    return sqrt(dist);
}

void R_distance(double *x, int *nr, int *nc, double *d, int *diag,
				int *method, double *p)
{
    int dc, i, j;
    size_t  ij;  // can exceed 2^31 - 1 
    double (*distfun)(double*, int, int, int, int) = NULL;
#ifdef _OPENMP
    int nthreads;
#endif
	
// dc = (*diag) ? 0 : 1; // diag=1:  we do the diagonal 
	dc = 0; // sans diag 

#ifdef _OPENMP
   		nthreads = 1; // for now 
    if (nthreads == 1) {
		// do the nthreads == 1 case without any OMP overhead to see if it matters on some platforms
		ij = 0;
		for(j = 0 ; j <= *nr ; j++)
			for(i = j+dc ; i < *nr ; i++)
				// d[ij++] = (*method != MINKOWSKI) ?
				// distfun(x, *nr, *nc, i, j) :
				// R_minkowski(x, *nr, *nc, i, j, *p);
				R_euclidean(x, *nr, *nc, i, j);
    }
    else
	//This produces uneven thread workloads since the outer loop is over the subdiagonal portions of columns.
 //An alternative would be to use a loop on ij and to compute the i and j values from ij.
#pragma omp parallel for num_threads(nthreads) default(none)	\
private(i, j, ij)						\
firstprivate(nr, dc, d, method, distfun, nc, x, p)
		for(j = 0 ; j <= *nr ; j++) {
			ij = j * (*nr - dc) + j - ((1 + j) * j) / 2;
			for(i = j+dc ; i < *nr ; i++)
				//d[ij++] = (*method != MINKOWSKI) ?
				//distfun(x, *nr, *nc, i, j) :
				//R_minkowski(x, *nr, *nc, i, j, *p);
				R_euclidean(x, *nr, *nc, i, j);
		}
#else
    ij = 0;
    for(j = 0 ; j <= *nr ; j++)
		for(i = j+dc ; i < *nr ; i++)
			R_euclidean(x, *nr, *nc, i, j);
			//d[ij++] = (*method != MINKOWSKI) ?
			//distfun(x, *nr, *nc, i, j) : R_minkowski(x, *nr, *nc, i, j, *p);
#endif
}*/
